"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.timestamp_pb2
import prodvana.proto.prodvana.events.types_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class Event(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    DETAILS_FIELD_NUMBER: builtins.int
    TIMESTAMP_FIELD_NUMBER: builtins.int
    RELATED_OBJECTS_FIELD_NUMBER: builtins.int
    ACTOR_FIELD_NUMBER: builtins.int
    id: builtins.str
    type: prodvana.proto.prodvana.events.types_pb2.EventType.ValueType
    title: builtins.str
    @property
    def details(self) -> prodvana.proto.prodvana.events.types_pb2.EventDetails: ...
    @property
    def timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def related_objects(self) -> global___RelatedObjects: ...
    actor: builtins.str
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        type: prodvana.proto.prodvana.events.types_pb2.EventType.ValueType = ...,
        title: builtins.str = ...,
        details: prodvana.proto.prodvana.events.types_pb2.EventDetails | None = ...,
        timestamp: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        related_objects: global___RelatedObjects | None = ...,
        actor: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["details", b"details", "related_objects", b"related_objects", "timestamp", b"timestamp"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["actor", b"actor", "details", b"details", "id", b"id", "related_objects", b"related_objects", "timestamp", b"timestamp", "title", b"title", "type", b"type"]) -> None: ...

global___Event = Event

class RelatedObjects(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class ExternalLogsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    APPLICATION_ID_FIELD_NUMBER: builtins.int
    SERVICE_ID_FIELD_NUMBER: builtins.int
    RELEASE_CHANNEL_ID_FIELD_NUMBER: builtins.int
    DESIRED_STATE_ID_FIELD_NUMBER: builtins.int
    ROOT_DESIRED_STATE_ID_FIELD_NUMBER: builtins.int
    RELEASE_ID_FIELD_NUMBER: builtins.int
    RUNTIME_ID_FIELD_NUMBER: builtins.int
    EXTERNAL_LOGS_FIELD_NUMBER: builtins.int
    application_id: builtins.str
    service_id: builtins.str
    release_channel_id: builtins.str
    desired_state_id: builtins.str
    root_desired_state_id: builtins.str
    release_id: builtins.str
    runtime_id: builtins.str
    @property
    def external_logs(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """next tag: 9"""
    def __init__(
        self,
        *,
        application_id: builtins.str = ...,
        service_id: builtins.str = ...,
        release_channel_id: builtins.str = ...,
        desired_state_id: builtins.str = ...,
        root_desired_state_id: builtins.str = ...,
        release_id: builtins.str = ...,
        runtime_id: builtins.str = ...,
        external_logs: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["application_id", b"application_id", "desired_state_id", b"desired_state_id", "external_logs", b"external_logs", "release_channel_id", b"release_channel_id", "release_id", b"release_id", "root_desired_state_id", b"root_desired_state_id", "runtime_id", b"runtime_id", "service_id", b"service_id"]) -> None: ...

global___RelatedObjects = RelatedObjects
