"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _Role:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _RoleEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_Role.ValueType], builtins.type):  # noqa: F821
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    UNSPECIFIED: _Role.ValueType  # 0
    ORG_ADMIN: _Role.ValueType  # 1
    CLOUD_ADMIN: _Role.ValueType  # 2
    SERVICE_OWNER: _Role.ValueType  # 3
    VIEWER: _Role.ValueType  # 4

class Role(_Role, metaclass=_RoleEnumTypeWrapper): ...

UNSPECIFIED: Role.ValueType  # 0
ORG_ADMIN: Role.ValueType  # 1
CLOUD_ADMIN: Role.ValueType  # 2
SERVICE_OWNER: Role.ValueType  # 3
VIEWER: Role.ValueType  # 4
global___Role = Role
