# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/object/manager.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from prodvana.proto.prodvana.labels import labels_pb2 as prodvana_dot_labels_dot_labels__pb2
from prodvana.proto.prodvana.object import meta_pb2 as prodvana_dot_object_dot_meta__pb2
from prodvana.proto.validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dprodvana/object/manager.proto\x12\x0fprodvana.object\x1a\x1cgoogle/api/annotations.proto\x1a\x1cprodvana/labels/labels.proto\x1a\x1aprodvana/object/meta.proto\x1a\x17validate/validate.proto\"(\n\x0eQueryObjectReq\x12\x16\n\x05query\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\"?\n\x0fQueryObjectResp\x12,\n\x07objects\x18\x01 \x03(\x0b\x32\x1b.prodvana.object.ObjectMeta\"E\n\x0cGetLabelsReq\x12)\n\x04type\x18\x01 \x01(\x0e\x32\x1b.prodvana.object.ObjectType\x12\n\n\x02id\x18\x02 \x01(\t\"M\n\rGetLabelsResp\x12\x30\n\x06labels\x18\x02 \x03(\x0b\x32 .prodvana.labels.LabelDefinitionJ\x04\x08\x01\x10\x02R\x04meta2\xe5\x01\n\rObjectManager\x12l\n\x0cQueryObjects\x12\x1f.prodvana.object.QueryObjectReq\x1a .prodvana.object.QueryObjectResp\"\x19\x82\xd3\xe4\x93\x02\x13\x12\x11/v1/objects/query\x12\x66\n\tGetLabels\x12\x1d.prodvana.object.GetLabelsReq\x1a\x1e.prodvana.object.GetLabelsResp\"\x1a\x82\xd3\xe4\x93\x02\x14\x12\x12/v1/objects/labelsBKZIgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/objectb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'prodvana.object.manager_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZIgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/object'
  _QUERYOBJECTREQ.fields_by_name['query']._options = None
  _QUERYOBJECTREQ.fields_by_name['query']._serialized_options = b'\372B\004r\002\020\001'
  _OBJECTMANAGER.methods_by_name['QueryObjects']._options = None
  _OBJECTMANAGER.methods_by_name['QueryObjects']._serialized_options = b'\202\323\344\223\002\023\022\021/v1/objects/query'
  _OBJECTMANAGER.methods_by_name['GetLabels']._options = None
  _OBJECTMANAGER.methods_by_name['GetLabels']._serialized_options = b'\202\323\344\223\002\024\022\022/v1/objects/labels'
  _globals['_QUERYOBJECTREQ']._serialized_start=163
  _globals['_QUERYOBJECTREQ']._serialized_end=203
  _globals['_QUERYOBJECTRESP']._serialized_start=205
  _globals['_QUERYOBJECTRESP']._serialized_end=268
  _globals['_GETLABELSREQ']._serialized_start=270
  _globals['_GETLABELSREQ']._serialized_end=339
  _globals['_GETLABELSRESP']._serialized_start=341
  _globals['_GETLABELSRESP']._serialized_end=418
  _globals['_OBJECTMANAGER']._serialized_start=421
  _globals['_OBJECTMANAGER']._serialized_end=650
# @@protoc_insertion_point(module_scope)
