# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/desired_state/manager.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from prodvana.proto.prodvana.async_task import task_metadata_pb2 as prodvana_dot_async__task_dot_task__metadata__pb2
from prodvana.proto.prodvana.desired_state.debug import debug_pb2 as prodvana_dot_desired__state_dot_debug_dot_debug__pb2
from prodvana.proto.prodvana.desired_state.maestro import maestro_pb2 as prodvana_dot_desired__state_dot_maestro_dot_maestro__pb2
from prodvana.proto.prodvana.desired_state.model import desired_state_pb2 as prodvana_dot_desired__state_dot_model_dot_desired__state__pb2
from prodvana.proto.prodvana.desired_state.model import entity_pb2 as prodvana_dot_desired__state_dot_model_dot_entity__pb2
from prodvana.proto.prodvana.service import service_config_pb2 as prodvana_dot_service_dot_service__config__pb2
from prodvana.proto.prodvana.version import source_metadata_pb2 as prodvana_dot_version_dot_source__metadata__pb2
from prodvana.proto.validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$prodvana/desired_state/manager.proto\x12\x16prodvana.desired_state\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\'prodvana/async_task/task_metadata.proto\x1a(prodvana/desired_state/debug/debug.proto\x1a,prodvana/desired_state/maestro/maestro.proto\x1a\x30prodvana/desired_state/model/desired_state.proto\x1a)prodvana/desired_state/model/entity.proto\x1a%prodvana/service/service_config.proto\x1a&prodvana/version/source_metadata.proto\x1a\x17validate/validate.proto\"\xf6\x02\n\x12SetDesiredStateReq\x12\x44\n\rdesired_state\x18\x01 \x01(\x0b\x32#.prodvana.desired_state.model.StateB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12\x10\n\x08rollback\x18\x02 \x01(\x08\x12,\n$bypass_preconditions_and_protections\x18\x06 \x01(\x08\x12(\n\x06source\x18\x03 \x01(\x0e\x32\x18.prodvana.version.Source\x12\x39\n\x0fsource_metadata\x18\x04 \x01(\x0b\x32 .prodvana.version.SourceMetadata\x12%\n\x1d\x66orce_async_set_desired_state\x18\x05 \x01(\x08\x12N\n\x17maestro_config_override\x18\x07 \x01(\x0b\x32-.prodvana.desired_state.maestro.MaestroConfig\"\xb4\x02\n\x17ValidateDesiredStateReq\x12\x44\n\rdesired_state\x18\x01 \x01(\x0b\x32#.prodvana.desired_state.model.StateB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12\x10\n\x08rollback\x18\x02 \x01(\x08\x12,\n$bypass_preconditions_and_protections\x18\x06 \x01(\x08\x12Q\n\x18service_instance_configs\x18\x03 \x03(\x0b\x32/.prodvana.service.CompiledServiceInstanceConfig\x12\x1c\n\x14label_expansion_only\x18\x04 \x01(\x08\x12\"\n\x1a\x64isregard_service_versions\x18\x05 \x01(\x08\"S\n\x13SetDesiredStateResp\x12\x1a\n\x10\x64\x65sired_state_id\x18\x01 \x01(\tH\x00\x12\x14\n\nrelease_id\x18\x02 \x01(\tH\x00\x42\n\n\x08id_oneof\"s\n\x16PreviewEntityGraphResp\x12?\n\x0c\x65ntity_graph\x18\x01 \x01(\x0b\x32).prodvana.desired_state.model.EntityGraph\x12\x18\n\x10\x64\x65sired_state_id\x18\x02 \x01(\t\"\x88\x01\n+GetServiceDesiredStateConvergenceSummaryReq\x12\x1c\n\x0b\x61pplication\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x18\n\x07service\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12!\n\x19\x66\x61st_no_deprecated_fields\x18\x03 \x01(\x08\"b\n\x12StatusExplanations\x12L\n\x13status_explanations\x18\x01 \x03(\x0b\x32/.prodvana.desired_state.model.StatusExplanation\"G\n\tDebugLogs\x12:\n\ndebug_logs\x18\x01 \x03(\x0b\x32&.prodvana.desired_state.model.DebugLog\"\xe3\x01\n\x16PendingSetDesiredState\x12\x18\n\x10\x64\x65sired_state_id\x18\x04 \x01(\t\x12\x43\n\x16\x63ompiled_desired_state\x18\x01 \x01(\x0b\x32#.prodvana.desired_state.model.State\x12\x34\n\x0btask_status\x18\x02 \x01(\x0e\x32\x1f.prodvana.async_task.TaskStatus\x12\x34\n\x0btask_result\x18\x03 \x01(\x0b\x32\x1f.prodvana.async_task.TaskResult\"\xba\x12\n\x13\x44\x65siredStateSummary\x12?\n\x0c\x65ntity_graph\x18\x0f \x01(\x0b\x32).prodvana.desired_state.model.EntityGraph\x12\x36\n\x12\x63reation_timestamp\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x39\n\x15last_update_timestamp\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x36\n\x12replaced_timestamp\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12@\n\x13input_desired_state\x18\x10 \x01(\x0b\x32#.prodvana.desired_state.model.State\x12:\n\rdesired_state\x18\x03 \x01(\x0b\x32#.prodvana.desired_state.model.State\x12;\n\x0estarting_state\x18\x01 \x01(\x0b\x32#.prodvana.desired_state.model.State\x12<\n\x0flast_seen_state\x18\x02 \x01(\x0b\x32#.prodvana.desired_state.model.State\x12\x34\n\x06status\x18\x13 \x01(\x0e\x32$.prodvana.desired_state.model.Status\x12(\n\x06source\x18\x11 \x01(\x0e\x32\x18.prodvana.version.Source\x12\x39\n\x0fsource_metadata\x18\x12 \x01(\x0b\x32 .prodvana.version.SourceMetadata\x12Q\n\x19pending_set_desired_state\x18\x14 \x01(\x0b\x32..prodvana.desired_state.PendingSetDesiredState\x12Y\n\x1aset_desired_state_metadata\x18\x15 \x01(\x0b\x32\x35.prodvana.desired_state.model.SetDesiredStateMetadata\x12K\n\x08statuses\x18\x04 \x03(\x0b\x32\x39.prodvana.desired_state.DesiredStateSummary.StatusesEntry\x12\x64\n\x15precondition_statuses\x18\x08 \x03(\x0b\x32\x45.prodvana.desired_state.DesiredStateSummary.PreconditionStatusesEntry\x12`\n\x13status_explanations\x18\t \x03(\x0b\x32\x43.prodvana.desired_state.DesiredStateSummary.StatusExplanationsEntry\x12N\n\ndebug_logs\x18\n \x03(\x0b\x32:.prodvana.desired_state.DesiredStateSummary.DebugLogsEntry\x12`\n\x13\x61\x63tion_explanations\x18\x0b \x03(\x0b\x32\x43.prodvana.desired_state.DesiredStateSummary.ActionExplanationsEntry\x12\x65\n\x16last_update_timestamps\x18\x0c \x03(\x0b\x32\x45.prodvana.desired_state.DesiredStateSummary.LastUpdateTimestampsEntry\x12g\n\x17last_fetched_timestamps\x18\r \x03(\x0b\x32\x46.prodvana.desired_state.DesiredStateSummary.LastFetchedTimestampsEntry\x12g\n\x17last_applied_timestamps\x18\x0e \x03(\x0b\x32\x46.prodvana.desired_state.DesiredStateSummary.LastAppliedTimestampsEntry\x1aU\n\rStatusesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x33\n\x05value\x18\x02 \x01(\x0e\x32$.prodvana.desired_state.model.Status:\x02\x38\x01\x1ai\n\x19PreconditionStatusesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12;\n\x05value\x18\x02 \x01(\x0b\x32,.prodvana.desired_state.model.ConditionState:\x02\x38\x01\x1a\x65\n\x17StatusExplanationsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x39\n\x05value\x18\x02 \x01(\x0b\x32*.prodvana.desired_state.StatusExplanations:\x02\x38\x01\x1aS\n\x0e\x44\x65\x62ugLogsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x30\n\x05value\x18\x02 \x01(\x0b\x32!.prodvana.desired_state.DebugLogs:\x02\x38\x01\x1aj\n\x17\x41\x63tionExplanationsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12>\n\x05value\x18\x02 \x01(\x0b\x32/.prodvana.desired_state.model.ActionExplanation:\x02\x38\x01\x1aW\n\x19LastUpdateTimestampsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12)\n\x05value\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp:\x02\x38\x01\x1aX\n\x1aLastFetchedTimestampsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12)\n\x05value\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp:\x02\x38\x01\x1aX\n\x1aLastAppliedTimestampsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12)\n\x05value\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp:\x02\x38\x01\"e\n\x1dGetDesiredStateConvergenceReq\x12!\n\x10\x64\x65sired_state_id\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12!\n\x19\x66\x61st_no_deprecated_fields\x18\x02 \x01(\x08\"e\n%GetDesiredStateConvergenceSummaryResp\x12<\n\x07summary\x18\x01 \x01(\x0b\x32+.prodvana.desired_state.DesiredStateSummary\"l\n,GetServiceDesiredStateConvergenceSummaryResp\x12<\n\x07summary\x18\x01 \x01(\x0b\x32+.prodvana.desired_state.DesiredStateSummary\"Y\n\x1fGetServiceLastConvergedStateReq\x12\x1c\n\x0b\x61pplication\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x18\n\x07service\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\"w\n GetServiceLastConvergedStateResp\x12S\n\x17service_instance_states\x18\x01 \x03(\x0b\x32\x32.prodvana.desired_state.model.ServiceInstanceState\"\xa4\x01\n GetServiceDesiredStateHistoryReq\x12\x1c\n\x0b\x61pplication\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x18\n\x07service\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x12\n\npage_token\x18\x03 \x01(\t\x12\x11\n\tpage_size\x18\x04 \x01(\x05\x12!\n\x19\x66\x61st_no_deprecated_fields\x18\x05 \x01(\x08\"\x81\x01\n!GetServiceDesiredStateHistoryResp\x12\x43\n\x0e\x64\x65sired_states\x18\x01 \x03(\x0b\x32+.prodvana.desired_state.DesiredStateSummary\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"7\n\x12GetDesiredStateReq\x12!\n\x10\x64\x65sired_state_id\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\"\x8e\x03\n\x13GetDesiredStateResp\x12:\n\rdesired_state\x18\x01 \x01(\x0b\x32#.prodvana.desired_state.model.State\x12\x43\n\x16\x63ompiled_desired_state\x18\x02 \x01(\x0b\x32#.prodvana.desired_state.model.State\x12Y\n\x1aset_desired_state_metadata\x18\x03 \x01(\x0b\x32\x35.prodvana.desired_state.model.SetDesiredStateMetadata\x12\x36\n\x12\x63reation_timestamp\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12(\n\x06source\x18\x05 \x01(\x0e\x32\x18.prodvana.version.Source\x12\x39\n\x0fsource_metadata\x18\x06 \x01(\x0b\x32 .prodvana.version.SourceMetadata\"\x95\x05\n\x17GetDesiredStateGraphReq\x12#\n\x10\x64\x65sired_state_id\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01H\x00\x12Z\n\x10query_by_service\x18\x06 \x01(\x0b\x32>.prodvana.desired_state.GetDesiredStateGraphReq.QueryByServiceH\x00\x12\x31\n\x05types\x18\x07 \x03(\x0e\x32\".prodvana.desired_state.model.Type\x12G\n\x14required_annotations\x18\x03 \x01(\x0b\x32).prodvana.desired_state.model.Annotations\x12\x1d\n\x15required_entity_names\x18\t \x03(\t\x12\r\n\x05\x64\x65pth\x18\x04 \x01(\x05\x12h\n\x19\x64\x65pth_overrides_by_status\x18\x08 \x03(\x0b\x32\x45.prodvana.desired_state.GetDesiredStateGraphReq.DepthOverrideByStatus\x12(\n include_desired_state_timestamps\x18\x05 \x01(\x08\x1aH\n\x0eQueryByService\x12\x1c\n\x0b\x61pplication\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x18\n\x07service\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x1a\\\n\x15\x44\x65pthOverrideByStatus\x12\x34\n\x06status\x18\x01 \x01(\x0e\x32$.prodvana.desired_state.model.Status\x12\r\n\x05\x64\x65pth\x18\x02 \x01(\x05\x42\x07\n\x05queryJ\x04\x08\x02\x10\x03R\x04type\"\xc3\x01\n\x16\x44\x65siredStateTimestamps\x12\x36\n\x12\x63reation_timestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x39\n\x15last_update_timestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x36\n\x12replaced_timestamp\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\xf2\x01\n\x18GetDesiredStateGraphResp\x12?\n\x0c\x65ntity_graph\x18\x01 \x01(\x0b\x32).prodvana.desired_state.model.EntityGraph\x12Q\n\x19pending_set_desired_state\x18\x02 \x01(\x0b\x32..prodvana.desired_state.PendingSetDesiredState\x12\x42\n\ntimestamps\x18\x03 \x01(\x0b\x32..prodvana.desired_state.DesiredStateTimestamps\"[\n!GetServiceLatestDesiredStateIdReq\x12\x1c\n\x0b\x61pplication\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x18\n\x07service\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\"\x91\x01\n\"GetServiceLatestDesiredStateIdResp\x12\x18\n\x10\x64\x65sired_state_id\x18\x01 \x01(\t\x12Q\n\x19pending_set_desired_state\x18\x02 \x01(\x0b\x32..prodvana.desired_state.PendingSetDesiredState\"\x83\x01\n\"GetServiceDesiredStateIdHistoryReq\x12\x1c\n\x0b\x61pplication\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x18\n\x07service\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x12\n\npage_token\x18\x03 \x01(\t\x12\x11\n\tpage_size\x18\x04 \x01(\x05\"Y\n#GetServiceDesiredStateIdHistoryResp\x12\x19\n\x11\x64\x65sired_state_ids\x18\x01 \x03(\t\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x9b\x01\n\x18ValidateDesiredStateResp\x12:\n\rdesired_state\x18\x01 \x01(\x0b\x32#.prodvana.desired_state.model.State\x12\x43\n\x16\x63ompiled_desired_state\x18\x02 \x01(\x0b\x32#.prodvana.desired_state.model.State\"|\n\x14SetManualApprovalReq\x12!\n\x10\x64\x65sired_state_id\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x16\n\x05topic\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x0e\n\x06reject\x18\x03 \x01(\x08\x12\x13\n\x0bsignal_type\x18\x05 \x01(\tJ\x04\x08\x04\x10\x05\"\x17\n\x15SetManualApprovalResp\"}\n\x12PromoteDeliveryReq\x12!\n\x10\x64\x65sired_state_id\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\r\n\x05stage\x18\x02 \x01(\x03\x12\x0c\n\x04\x66ull\x18\x03 \x01(\x08\x12\x0e\n\x06reject\x18\x05 \x01(\x08\x12\x17\n\x06source\x18\x04 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\"\x15\n\x13PromoteDeliveryResp\"Q\n\x13\x42ypassProtectionReq\x12!\n\x10\x64\x65sired_state_id\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x17\n\x06source\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\"\x16\n\x14\x42ypassProtectionResp\"\xb7\x01\n\x16ListMaestroReleasesReq\x12\x45\n\tentity_id\x18\x01 \x01(\x0b\x32(.prodvana.desired_state.model.IdentifierB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12\x12\n\ndescending\x18\x05 \x01(\x08\x12\x1b\n\x13starting_release_id\x18\x02 \x01(\t\x12\x12\n\npage_token\x18\x03 \x01(\t\x12\x11\n\tpage_size\x18\x04 \x01(\x05\"|\n\x17ListMaestroReleasesResp\x12H\n\x10maestro_releases\x18\x01 \x03(\x0b\x32..prodvana.desired_state.maestro.MaestroRelease\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"3\n\x14GetMaestroReleaseReq\x12\x1b\n\nrelease_id\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\"`\n\x15GetMaestroReleaseResp\x12G\n\x0fmaestro_release\x18\x01 \x01(\x0b\x32..prodvana.desired_state.maestro.MaestroRelease\"\x9b\x01\n\x17ListCombinedReleasesReq\x12\x45\n\tentity_id\x18\x01 \x01(\x0b\x32(.prodvana.desired_state.model.IdentifierB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12\x12\n\ndescending\x18\x04 \x01(\x08\x12\x12\n\npage_token\x18\x02 \x01(\t\x12\x11\n\tpage_size\x18\x03 \x01(\x05\"\x93\x01\n\x1eListServiceCombinedReleasesReq\x12\x1c\n\x0b\x61pplication\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x18\n\x07service\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x12\n\ndescending\x18\x03 \x01(\x08\x12\x12\n\npage_token\x18\x04 \x01(\t\x12\x11\n\tpage_size\x18\x05 \x01(\x05\"\x86\x02\n\x18ListCombinedReleasesResp\x12J\n\x08releases\x18\x01 \x03(\x0b\x32\x38.prodvana.desired_state.ListCombinedReleasesResp.Release\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\x1a\x84\x01\n\x07Release\x12\x1a\n\x10\x64\x65sired_state_id\x18\x01 \x01(\tH\x00\x12\x14\n\nrelease_id\x18\x02 \x01(\tH\x00\x12\x36\n\x12\x63reation_timestamp\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x0f\n\rrelease_oneof\"p\n\'GetLatestCombinedReleaseDesiredStateReq\x12\x45\n\tentity_id\x18\x01 \x01(\x0b\x32(.prodvana.desired_state.model.IdentifierB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\"h\n.GetServiceLatestCombinedReleaseDesiredStateReq\x12\x1c\n\x0b\x61pplication\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x18\n\x07service\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\"\xa9\x03\n(GetLatestCombinedReleaseDesiredStateResp\x12@\n\x13input_desired_state\x18\x01 \x01(\x0b\x32#.prodvana.desired_state.model.State\x12\x43\n\x16\x63ompiled_desired_state\x18\x02 \x01(\x0b\x32#.prodvana.desired_state.model.State\x12Y\n\x1aset_desired_state_metadata\x18\x03 \x01(\x0b\x32\x35.prodvana.desired_state.model.SetDesiredStateMetadata\x12\x36\n\x12\x63reation_timestamp\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12(\n\x06source\x18\x05 \x01(\x0e\x32\x18.prodvana.version.Source\x12\x39\n\x0fsource_metadata\x18\x06 \x01(\x0b\x32 .prodvana.version.SourceMetadata2\x9d \n\x13\x44\x65siredStateManager\x12\x89\x01\n\x0fSetDesiredState\x12*.prodvana.desired_state.SetDesiredStateReq\x1a+.prodvana.desired_state.SetDesiredStateResp\"\x1d\x82\xd3\xe4\x93\x02\x17\"\x12/v1/desired_states:\x01*\x12\x97\x01\n\x12PreviewEntityGraph\x12*.prodvana.desired_state.SetDesiredStateReq\x1a..prodvana.desired_state.PreviewEntityGraphResp\"%\x82\xd3\xe4\x93\x02\x1f\"\x1a/v1/desired_states/preview:\x01*\x12\x89\x02\n(GetServiceDesiredStateConvergenceSummary\x12\x43.prodvana.desired_state.GetServiceDesiredStateConvergenceSummaryReq\x1a\x44.prodvana.desired_state.GetServiceDesiredStateConvergenceSummaryResp\"R\x82\xd3\xe4\x93\x02L\x12J/v1/applications/{application=*}/services/{service=*}/latest_desired_state\x12\xee\x01\n\x1eGetServiceLatestDesiredStateId\x12\x39.prodvana.desired_state.GetServiceLatestDesiredStateIdReq\x1a:.prodvana.desired_state.GetServiceLatestDesiredStateIdResp\"U\x82\xd3\xe4\x93\x02O\x12M/v1/applications/{application=*}/services/{service=*}/latest_desired_state_id\x12\xf2\x01\n\x1fGetServiceDesiredStateIdHistory\x12:.prodvana.desired_state.GetServiceDesiredStateIdHistoryReq\x1a;.prodvana.desired_state.GetServiceDesiredStateIdHistoryResp\"V\x82\xd3\xe4\x93\x02P\x12N/v1/applications/{application=*}/services/{service=*}/desired_state_id_history\x12\xe0\x01\n\x1dGetServiceLastConvergedStates\x12\x37.prodvana.desired_state.GetServiceLastConvergedStateReq\x1a\x38.prodvana.desired_state.GetServiceLastConvergedStateResp\"L\x82\xd3\xe4\x93\x02\x46\x12\x44/v1/applications/{application=*}/services/{service=*}/last_converged\x12\xe2\x01\n\x1dGetServiceDesiredStateHistory\x12\x38.prodvana.desired_state.GetServiceDesiredStateHistoryReq\x1a\x39.prodvana.desired_state.GetServiceDesiredStateHistoryResp\"L\x82\xd3\xe4\x93\x02\x46\x12\x44/v1/applications/{application=*}/services/{service=*}/desired_states\x12\x9b\x01\n\x0fGetDesiredState\x12*.prodvana.desired_state.GetDesiredStateReq\x1a+.prodvana.desired_state.GetDesiredStateResp\"/\x82\xd3\xe4\x93\x02)\x12\'/v1/desired_states/{desired_state_id=*}\x12\x9e\x01\n\x14GetDesiredStateGraph\x12/.prodvana.desired_state.GetDesiredStateGraphReq\x1a\x30.prodvana.desired_state.GetDesiredStateGraphResp\"#\x82\xd3\xe4\x93\x02\x1d\"\x18/v1/desired_states/graph:\x01*\x12\xd2\x01\n!GetDesiredStateConvergenceSummary\x12\x35.prodvana.desired_state.GetDesiredStateConvergenceReq\x1a=.prodvana.desired_state.GetDesiredStateConvergenceSummaryResp\"7\x82\xd3\xe4\x93\x02\x31\x12//v1/desired_states/{desired_state_id=*}/summary\x12\xa1\x01\n\x14ValidateDesiredState\x12/.prodvana.desired_state.ValidateDesiredStateReq\x1a\x30.prodvana.desired_state.ValidateDesiredStateResp\"&\x82\xd3\xe4\x93\x02 \"\x1b/v1/desired_states/validate:\x01*\x12\xa8\x01\n\x11SetManualApproval\x12,.prodvana.desired_state.SetManualApprovalReq\x1a-.prodvana.desired_state.SetManualApprovalResp\"6\x82\xd3\xe4\x93\x02\x30\"+/v1/desired_states/approve_manual_condition:\x01*\x12\x9a\x01\n\x0fPromoteDelivery\x12*.prodvana.desired_state.PromoteDeliveryReq\x1a+.prodvana.desired_state.PromoteDeliveryResp\".\x82\xd3\xe4\x93\x02(\"#/v1/desired_states/promote_delivery:\x01*\x12\x9e\x01\n\x10\x42ypassProtection\x12+.prodvana.desired_state.BypassProtectionReq\x1a,.prodvana.desired_state.BypassProtectionResp\"/\x82\xd3\xe4\x93\x02)\"$/v1/desired_states/bypass_protection:\x01*\x12\xa3\x01\n\x13ListMaestroReleases\x12..prodvana.desired_state.ListMaestroReleasesReq\x1a/.prodvana.desired_state.ListMaestroReleasesResp\"+\x82\xd3\xe4\x93\x02%\x12#/v1/desired_states/maestro_releases\x12\xac\x01\n\x11GetMaestroRelease\x12,.prodvana.desired_state.GetMaestroReleaseReq\x1a-.prodvana.desired_state.GetMaestroReleaseResp\":\x82\xd3\xe4\x93\x02\x34\x12\x32/v1/desired_states/maestro_releases/{release_id=*}\x12\xa7\x01\n\x14ListCombinedReleases\x12/.prodvana.desired_state.ListCombinedReleasesReq\x1a\x30.prodvana.desired_state.ListCombinedReleasesResp\",\x82\xd3\xe4\x93\x02&\x12$/v1/desired_states/combined_releases\x12\xd8\x01\n\x1bListServiceCombinedReleases\x12\x36.prodvana.desired_state.ListServiceCombinedReleasesReq\x1a\x30.prodvana.desired_state.ListCombinedReleasesResp\"O\x82\xd3\xe4\x93\x02I\x12G/v1/applications/{application=*}/services/{service=*}/combined_releases\x12\xec\x01\n$GetLatestCombinedReleaseDesiredState\x12?.prodvana.desired_state.GetLatestCombinedReleaseDesiredStateReq\x1a@.prodvana.desired_state.GetLatestCombinedReleaseDesiredStateResp\"A\x82\xd3\xe4\x93\x02;\x12\x39/v1/desired_states/combined_releases/latest_desired_state\x12\x9d\x02\n+GetServiceLatestCombinedReleaseDesiredState\x12\x46.prodvana.desired_state.GetServiceLatestCombinedReleaseDesiredStateReq\x1a@.prodvana.desired_state.GetLatestCombinedReleaseDesiredStateResp\"d\x82\xd3\xe4\x93\x02^\x12\\/v1/applications/{application=*}/services/{service=*}/combined_releases/latest_desired_state\x12\x9b\x01\n\rGetDebugState\x12*.prodvana.desired_state.GetDesiredStateReq\x1a\'.prodvana.desired_state.debug.DumpState\"5\x82\xd3\xe4\x93\x02/\x12-/v1/desired_states/{desired_state_id=*}/debugBRZPgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/desired_stateb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'prodvana.desired_state.manager_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZPgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/desired_state'
  _SETDESIREDSTATEREQ.fields_by_name['desired_state']._options = None
  _SETDESIREDSTATEREQ.fields_by_name['desired_state']._serialized_options = b'\372B\005\212\001\002\020\001'
  _VALIDATEDESIREDSTATEREQ.fields_by_name['desired_state']._options = None
  _VALIDATEDESIREDSTATEREQ.fields_by_name['desired_state']._serialized_options = b'\372B\005\212\001\002\020\001'
  _GETSERVICEDESIREDSTATECONVERGENCESUMMARYREQ.fields_by_name['application']._options = None
  _GETSERVICEDESIREDSTATECONVERGENCESUMMARYREQ.fields_by_name['application']._serialized_options = b'\372B\004r\002\020\001'
  _GETSERVICEDESIREDSTATECONVERGENCESUMMARYREQ.fields_by_name['service']._options = None
  _GETSERVICEDESIREDSTATECONVERGENCESUMMARYREQ.fields_by_name['service']._serialized_options = b'\372B\004r\002\020\001'
  _DESIREDSTATESUMMARY_STATUSESENTRY._options = None
  _DESIREDSTATESUMMARY_STATUSESENTRY._serialized_options = b'8\001'
  _DESIREDSTATESUMMARY_PRECONDITIONSTATUSESENTRY._options = None
  _DESIREDSTATESUMMARY_PRECONDITIONSTATUSESENTRY._serialized_options = b'8\001'
  _DESIREDSTATESUMMARY_STATUSEXPLANATIONSENTRY._options = None
  _DESIREDSTATESUMMARY_STATUSEXPLANATIONSENTRY._serialized_options = b'8\001'
  _DESIREDSTATESUMMARY_DEBUGLOGSENTRY._options = None
  _DESIREDSTATESUMMARY_DEBUGLOGSENTRY._serialized_options = b'8\001'
  _DESIREDSTATESUMMARY_ACTIONEXPLANATIONSENTRY._options = None
  _DESIREDSTATESUMMARY_ACTIONEXPLANATIONSENTRY._serialized_options = b'8\001'
  _DESIREDSTATESUMMARY_LASTUPDATETIMESTAMPSENTRY._options = None
  _DESIREDSTATESUMMARY_LASTUPDATETIMESTAMPSENTRY._serialized_options = b'8\001'
  _DESIREDSTATESUMMARY_LASTFETCHEDTIMESTAMPSENTRY._options = None
  _DESIREDSTATESUMMARY_LASTFETCHEDTIMESTAMPSENTRY._serialized_options = b'8\001'
  _DESIREDSTATESUMMARY_LASTAPPLIEDTIMESTAMPSENTRY._options = None
  _DESIREDSTATESUMMARY_LASTAPPLIEDTIMESTAMPSENTRY._serialized_options = b'8\001'
  _GETDESIREDSTATECONVERGENCEREQ.fields_by_name['desired_state_id']._options = None
  _GETDESIREDSTATECONVERGENCEREQ.fields_by_name['desired_state_id']._serialized_options = b'\372B\004r\002\020\001'
  _GETSERVICELASTCONVERGEDSTATEREQ.fields_by_name['application']._options = None
  _GETSERVICELASTCONVERGEDSTATEREQ.fields_by_name['application']._serialized_options = b'\372B\004r\002\020\001'
  _GETSERVICELASTCONVERGEDSTATEREQ.fields_by_name['service']._options = None
  _GETSERVICELASTCONVERGEDSTATEREQ.fields_by_name['service']._serialized_options = b'\372B\004r\002\020\001'
  _GETSERVICEDESIREDSTATEHISTORYREQ.fields_by_name['application']._options = None
  _GETSERVICEDESIREDSTATEHISTORYREQ.fields_by_name['application']._serialized_options = b'\372B\004r\002\020\001'
  _GETSERVICEDESIREDSTATEHISTORYREQ.fields_by_name['service']._options = None
  _GETSERVICEDESIREDSTATEHISTORYREQ.fields_by_name['service']._serialized_options = b'\372B\004r\002\020\001'
  _GETDESIREDSTATEREQ.fields_by_name['desired_state_id']._options = None
  _GETDESIREDSTATEREQ.fields_by_name['desired_state_id']._serialized_options = b'\372B\004r\002\020\001'
  _GETDESIREDSTATEGRAPHREQ_QUERYBYSERVICE.fields_by_name['application']._options = None
  _GETDESIREDSTATEGRAPHREQ_QUERYBYSERVICE.fields_by_name['application']._serialized_options = b'\372B\004r\002\020\001'
  _GETDESIREDSTATEGRAPHREQ_QUERYBYSERVICE.fields_by_name['service']._options = None
  _GETDESIREDSTATEGRAPHREQ_QUERYBYSERVICE.fields_by_name['service']._serialized_options = b'\372B\004r\002\020\001'
  _GETDESIREDSTATEGRAPHREQ.fields_by_name['desired_state_id']._options = None
  _GETDESIREDSTATEGRAPHREQ.fields_by_name['desired_state_id']._serialized_options = b'\372B\004r\002\020\001'
  _GETSERVICELATESTDESIREDSTATEIDREQ.fields_by_name['application']._options = None
  _GETSERVICELATESTDESIREDSTATEIDREQ.fields_by_name['application']._serialized_options = b'\372B\004r\002\020\001'
  _GETSERVICELATESTDESIREDSTATEIDREQ.fields_by_name['service']._options = None
  _GETSERVICELATESTDESIREDSTATEIDREQ.fields_by_name['service']._serialized_options = b'\372B\004r\002\020\001'
  _GETSERVICEDESIREDSTATEIDHISTORYREQ.fields_by_name['application']._options = None
  _GETSERVICEDESIREDSTATEIDHISTORYREQ.fields_by_name['application']._serialized_options = b'\372B\004r\002\020\001'
  _GETSERVICEDESIREDSTATEIDHISTORYREQ.fields_by_name['service']._options = None
  _GETSERVICEDESIREDSTATEIDHISTORYREQ.fields_by_name['service']._serialized_options = b'\372B\004r\002\020\001'
  _SETMANUALAPPROVALREQ.fields_by_name['desired_state_id']._options = None
  _SETMANUALAPPROVALREQ.fields_by_name['desired_state_id']._serialized_options = b'\372B\004r\002\020\001'
  _SETMANUALAPPROVALREQ.fields_by_name['topic']._options = None
  _SETMANUALAPPROVALREQ.fields_by_name['topic']._serialized_options = b'\372B\004r\002\020\001'
  _PROMOTEDELIVERYREQ.fields_by_name['desired_state_id']._options = None
  _PROMOTEDELIVERYREQ.fields_by_name['desired_state_id']._serialized_options = b'\372B\004r\002\020\001'
  _PROMOTEDELIVERYREQ.fields_by_name['source']._options = None
  _PROMOTEDELIVERYREQ.fields_by_name['source']._serialized_options = b'\372B\004r\002\020\001'
  _BYPASSPROTECTIONREQ.fields_by_name['desired_state_id']._options = None
  _BYPASSPROTECTIONREQ.fields_by_name['desired_state_id']._serialized_options = b'\372B\004r\002\020\001'
  _BYPASSPROTECTIONREQ.fields_by_name['source']._options = None
  _BYPASSPROTECTIONREQ.fields_by_name['source']._serialized_options = b'\372B\004r\002\020\001'
  _LISTMAESTRORELEASESREQ.fields_by_name['entity_id']._options = None
  _LISTMAESTRORELEASESREQ.fields_by_name['entity_id']._serialized_options = b'\372B\005\212\001\002\020\001'
  _GETMAESTRORELEASEREQ.fields_by_name['release_id']._options = None
  _GETMAESTRORELEASEREQ.fields_by_name['release_id']._serialized_options = b'\372B\004r\002\020\001'
  _LISTCOMBINEDRELEASESREQ.fields_by_name['entity_id']._options = None
  _LISTCOMBINEDRELEASESREQ.fields_by_name['entity_id']._serialized_options = b'\372B\005\212\001\002\020\001'
  _LISTSERVICECOMBINEDRELEASESREQ.fields_by_name['application']._options = None
  _LISTSERVICECOMBINEDRELEASESREQ.fields_by_name['application']._serialized_options = b'\372B\004r\002\020\001'
  _LISTSERVICECOMBINEDRELEASESREQ.fields_by_name['service']._options = None
  _LISTSERVICECOMBINEDRELEASESREQ.fields_by_name['service']._serialized_options = b'\372B\004r\002\020\001'
  _GETLATESTCOMBINEDRELEASEDESIREDSTATEREQ.fields_by_name['entity_id']._options = None
  _GETLATESTCOMBINEDRELEASEDESIREDSTATEREQ.fields_by_name['entity_id']._serialized_options = b'\372B\005\212\001\002\020\001'
  _GETSERVICELATESTCOMBINEDRELEASEDESIREDSTATEREQ.fields_by_name['application']._options = None
  _GETSERVICELATESTCOMBINEDRELEASEDESIREDSTATEREQ.fields_by_name['application']._serialized_options = b'\372B\004r\002\020\001'
  _GETSERVICELATESTCOMBINEDRELEASEDESIREDSTATEREQ.fields_by_name['service']._options = None
  _GETSERVICELATESTCOMBINEDRELEASEDESIREDSTATEREQ.fields_by_name['service']._serialized_options = b'\372B\004r\002\020\001'
  _DESIREDSTATEMANAGER.methods_by_name['SetDesiredState']._options = None
  _DESIREDSTATEMANAGER.methods_by_name['SetDesiredState']._serialized_options = b'\202\323\344\223\002\027\"\022/v1/desired_states:\001*'
  _DESIREDSTATEMANAGER.methods_by_name['PreviewEntityGraph']._options = None
  _DESIREDSTATEMANAGER.methods_by_name['PreviewEntityGraph']._serialized_options = b'\202\323\344\223\002\037\"\032/v1/desired_states/preview:\001*'
  _DESIREDSTATEMANAGER.methods_by_name['GetServiceDesiredStateConvergenceSummary']._options = None
  _DESIREDSTATEMANAGER.methods_by_name['GetServiceDesiredStateConvergenceSummary']._serialized_options = b'\202\323\344\223\002L\022J/v1/applications/{application=*}/services/{service=*}/latest_desired_state'
  _DESIREDSTATEMANAGER.methods_by_name['GetServiceLatestDesiredStateId']._options = None
  _DESIREDSTATEMANAGER.methods_by_name['GetServiceLatestDesiredStateId']._serialized_options = b'\202\323\344\223\002O\022M/v1/applications/{application=*}/services/{service=*}/latest_desired_state_id'
  _DESIREDSTATEMANAGER.methods_by_name['GetServiceDesiredStateIdHistory']._options = None
  _DESIREDSTATEMANAGER.methods_by_name['GetServiceDesiredStateIdHistory']._serialized_options = b'\202\323\344\223\002P\022N/v1/applications/{application=*}/services/{service=*}/desired_state_id_history'
  _DESIREDSTATEMANAGER.methods_by_name['GetServiceLastConvergedStates']._options = None
  _DESIREDSTATEMANAGER.methods_by_name['GetServiceLastConvergedStates']._serialized_options = b'\202\323\344\223\002F\022D/v1/applications/{application=*}/services/{service=*}/last_converged'
  _DESIREDSTATEMANAGER.methods_by_name['GetServiceDesiredStateHistory']._options = None
  _DESIREDSTATEMANAGER.methods_by_name['GetServiceDesiredStateHistory']._serialized_options = b'\202\323\344\223\002F\022D/v1/applications/{application=*}/services/{service=*}/desired_states'
  _DESIREDSTATEMANAGER.methods_by_name['GetDesiredState']._options = None
  _DESIREDSTATEMANAGER.methods_by_name['GetDesiredState']._serialized_options = b'\202\323\344\223\002)\022\'/v1/desired_states/{desired_state_id=*}'
  _DESIREDSTATEMANAGER.methods_by_name['GetDesiredStateGraph']._options = None
  _DESIREDSTATEMANAGER.methods_by_name['GetDesiredStateGraph']._serialized_options = b'\202\323\344\223\002\035\"\030/v1/desired_states/graph:\001*'
  _DESIREDSTATEMANAGER.methods_by_name['GetDesiredStateConvergenceSummary']._options = None
  _DESIREDSTATEMANAGER.methods_by_name['GetDesiredStateConvergenceSummary']._serialized_options = b'\202\323\344\223\0021\022//v1/desired_states/{desired_state_id=*}/summary'
  _DESIREDSTATEMANAGER.methods_by_name['ValidateDesiredState']._options = None
  _DESIREDSTATEMANAGER.methods_by_name['ValidateDesiredState']._serialized_options = b'\202\323\344\223\002 \"\033/v1/desired_states/validate:\001*'
  _DESIREDSTATEMANAGER.methods_by_name['SetManualApproval']._options = None
  _DESIREDSTATEMANAGER.methods_by_name['SetManualApproval']._serialized_options = b'\202\323\344\223\0020\"+/v1/desired_states/approve_manual_condition:\001*'
  _DESIREDSTATEMANAGER.methods_by_name['PromoteDelivery']._options = None
  _DESIREDSTATEMANAGER.methods_by_name['PromoteDelivery']._serialized_options = b'\202\323\344\223\002(\"#/v1/desired_states/promote_delivery:\001*'
  _DESIREDSTATEMANAGER.methods_by_name['BypassProtection']._options = None
  _DESIREDSTATEMANAGER.methods_by_name['BypassProtection']._serialized_options = b'\202\323\344\223\002)\"$/v1/desired_states/bypass_protection:\001*'
  _DESIREDSTATEMANAGER.methods_by_name['ListMaestroReleases']._options = None
  _DESIREDSTATEMANAGER.methods_by_name['ListMaestroReleases']._serialized_options = b'\202\323\344\223\002%\022#/v1/desired_states/maestro_releases'
  _DESIREDSTATEMANAGER.methods_by_name['GetMaestroRelease']._options = None
  _DESIREDSTATEMANAGER.methods_by_name['GetMaestroRelease']._serialized_options = b'\202\323\344\223\0024\0222/v1/desired_states/maestro_releases/{release_id=*}'
  _DESIREDSTATEMANAGER.methods_by_name['ListCombinedReleases']._options = None
  _DESIREDSTATEMANAGER.methods_by_name['ListCombinedReleases']._serialized_options = b'\202\323\344\223\002&\022$/v1/desired_states/combined_releases'
  _DESIREDSTATEMANAGER.methods_by_name['ListServiceCombinedReleases']._options = None
  _DESIREDSTATEMANAGER.methods_by_name['ListServiceCombinedReleases']._serialized_options = b'\202\323\344\223\002I\022G/v1/applications/{application=*}/services/{service=*}/combined_releases'
  _DESIREDSTATEMANAGER.methods_by_name['GetLatestCombinedReleaseDesiredState']._options = None
  _DESIREDSTATEMANAGER.methods_by_name['GetLatestCombinedReleaseDesiredState']._serialized_options = b'\202\323\344\223\002;\0229/v1/desired_states/combined_releases/latest_desired_state'
  _DESIREDSTATEMANAGER.methods_by_name['GetServiceLatestCombinedReleaseDesiredState']._options = None
  _DESIREDSTATEMANAGER.methods_by_name['GetServiceLatestCombinedReleaseDesiredState']._serialized_options = b'\202\323\344\223\002^\022\\/v1/applications/{application=*}/services/{service=*}/combined_releases/latest_desired_state'
  _DESIREDSTATEMANAGER.methods_by_name['GetDebugState']._options = None
  _DESIREDSTATEMANAGER.methods_by_name['GetDebugState']._serialized_options = b'\202\323\344\223\002/\022-/v1/desired_states/{desired_state_id=*}/debug'
  _globals['_SETDESIREDSTATEREQ']._serialized_start=454
  _globals['_SETDESIREDSTATEREQ']._serialized_end=828
  _globals['_VALIDATEDESIREDSTATEREQ']._serialized_start=831
  _globals['_VALIDATEDESIREDSTATEREQ']._serialized_end=1139
  _globals['_SETDESIREDSTATERESP']._serialized_start=1141
  _globals['_SETDESIREDSTATERESP']._serialized_end=1224
  _globals['_PREVIEWENTITYGRAPHRESP']._serialized_start=1226
  _globals['_PREVIEWENTITYGRAPHRESP']._serialized_end=1341
  _globals['_GETSERVICEDESIREDSTATECONVERGENCESUMMARYREQ']._serialized_start=1344
  _globals['_GETSERVICEDESIREDSTATECONVERGENCESUMMARYREQ']._serialized_end=1480
  _globals['_STATUSEXPLANATIONS']._serialized_start=1482
  _globals['_STATUSEXPLANATIONS']._serialized_end=1580
  _globals['_DEBUGLOGS']._serialized_start=1582
  _globals['_DEBUGLOGS']._serialized_end=1653
  _globals['_PENDINGSETDESIREDSTATE']._serialized_start=1656
  _globals['_PENDINGSETDESIREDSTATE']._serialized_end=1883
  _globals['_DESIREDSTATESUMMARY']._serialized_start=1886
  _globals['_DESIREDSTATESUMMARY']._serialized_end=4248
  _globals['_DESIREDSTATESUMMARY_STATUSESENTRY']._serialized_start=3491
  _globals['_DESIREDSTATESUMMARY_STATUSESENTRY']._serialized_end=3576
  _globals['_DESIREDSTATESUMMARY_PRECONDITIONSTATUSESENTRY']._serialized_start=3578
  _globals['_DESIREDSTATESUMMARY_PRECONDITIONSTATUSESENTRY']._serialized_end=3683
  _globals['_DESIREDSTATESUMMARY_STATUSEXPLANATIONSENTRY']._serialized_start=3685
  _globals['_DESIREDSTATESUMMARY_STATUSEXPLANATIONSENTRY']._serialized_end=3786
  _globals['_DESIREDSTATESUMMARY_DEBUGLOGSENTRY']._serialized_start=3788
  _globals['_DESIREDSTATESUMMARY_DEBUGLOGSENTRY']._serialized_end=3871
  _globals['_DESIREDSTATESUMMARY_ACTIONEXPLANATIONSENTRY']._serialized_start=3873
  _globals['_DESIREDSTATESUMMARY_ACTIONEXPLANATIONSENTRY']._serialized_end=3979
  _globals['_DESIREDSTATESUMMARY_LASTUPDATETIMESTAMPSENTRY']._serialized_start=3981
  _globals['_DESIREDSTATESUMMARY_LASTUPDATETIMESTAMPSENTRY']._serialized_end=4068
  _globals['_DESIREDSTATESUMMARY_LASTFETCHEDTIMESTAMPSENTRY']._serialized_start=4070
  _globals['_DESIREDSTATESUMMARY_LASTFETCHEDTIMESTAMPSENTRY']._serialized_end=4158
  _globals['_DESIREDSTATESUMMARY_LASTAPPLIEDTIMESTAMPSENTRY']._serialized_start=4160
  _globals['_DESIREDSTATESUMMARY_LASTAPPLIEDTIMESTAMPSENTRY']._serialized_end=4248
  _globals['_GETDESIREDSTATECONVERGENCEREQ']._serialized_start=4250
  _globals['_GETDESIREDSTATECONVERGENCEREQ']._serialized_end=4351
  _globals['_GETDESIREDSTATECONVERGENCESUMMARYRESP']._serialized_start=4353
  _globals['_GETDESIREDSTATECONVERGENCESUMMARYRESP']._serialized_end=4454
  _globals['_GETSERVICEDESIREDSTATECONVERGENCESUMMARYRESP']._serialized_start=4456
  _globals['_GETSERVICEDESIREDSTATECONVERGENCESUMMARYRESP']._serialized_end=4564
  _globals['_GETSERVICELASTCONVERGEDSTATEREQ']._serialized_start=4566
  _globals['_GETSERVICELASTCONVERGEDSTATEREQ']._serialized_end=4655
  _globals['_GETSERVICELASTCONVERGEDSTATERESP']._serialized_start=4657
  _globals['_GETSERVICELASTCONVERGEDSTATERESP']._serialized_end=4776
  _globals['_GETSERVICEDESIREDSTATEHISTORYREQ']._serialized_start=4779
  _globals['_GETSERVICEDESIREDSTATEHISTORYREQ']._serialized_end=4943
  _globals['_GETSERVICEDESIREDSTATEHISTORYRESP']._serialized_start=4946
  _globals['_GETSERVICEDESIREDSTATEHISTORYRESP']._serialized_end=5075
  _globals['_GETDESIREDSTATEREQ']._serialized_start=5077
  _globals['_GETDESIREDSTATEREQ']._serialized_end=5132
  _globals['_GETDESIREDSTATERESP']._serialized_start=5135
  _globals['_GETDESIREDSTATERESP']._serialized_end=5533
  _globals['_GETDESIREDSTATEGRAPHREQ']._serialized_start=5536
  _globals['_GETDESIREDSTATEGRAPHREQ']._serialized_end=6197
  _globals['_GETDESIREDSTATEGRAPHREQ_QUERYBYSERVICE']._serialized_start=6010
  _globals['_GETDESIREDSTATEGRAPHREQ_QUERYBYSERVICE']._serialized_end=6082
  _globals['_GETDESIREDSTATEGRAPHREQ_DEPTHOVERRIDEBYSTATUS']._serialized_start=6084
  _globals['_GETDESIREDSTATEGRAPHREQ_DEPTHOVERRIDEBYSTATUS']._serialized_end=6176
  _globals['_DESIREDSTATETIMESTAMPS']._serialized_start=6200
  _globals['_DESIREDSTATETIMESTAMPS']._serialized_end=6395
  _globals['_GETDESIREDSTATEGRAPHRESP']._serialized_start=6398
  _globals['_GETDESIREDSTATEGRAPHRESP']._serialized_end=6640
  _globals['_GETSERVICELATESTDESIREDSTATEIDREQ']._serialized_start=6642
  _globals['_GETSERVICELATESTDESIREDSTATEIDREQ']._serialized_end=6733
  _globals['_GETSERVICELATESTDESIREDSTATEIDRESP']._serialized_start=6736
  _globals['_GETSERVICELATESTDESIREDSTATEIDRESP']._serialized_end=6881
  _globals['_GETSERVICEDESIREDSTATEIDHISTORYREQ']._serialized_start=6884
  _globals['_GETSERVICEDESIREDSTATEIDHISTORYREQ']._serialized_end=7015
  _globals['_GETSERVICEDESIREDSTATEIDHISTORYRESP']._serialized_start=7017
  _globals['_GETSERVICEDESIREDSTATEIDHISTORYRESP']._serialized_end=7106
  _globals['_VALIDATEDESIREDSTATERESP']._serialized_start=7109
  _globals['_VALIDATEDESIREDSTATERESP']._serialized_end=7264
  _globals['_SETMANUALAPPROVALREQ']._serialized_start=7266
  _globals['_SETMANUALAPPROVALREQ']._serialized_end=7390
  _globals['_SETMANUALAPPROVALRESP']._serialized_start=7392
  _globals['_SETMANUALAPPROVALRESP']._serialized_end=7415
  _globals['_PROMOTEDELIVERYREQ']._serialized_start=7417
  _globals['_PROMOTEDELIVERYREQ']._serialized_end=7542
  _globals['_PROMOTEDELIVERYRESP']._serialized_start=7544
  _globals['_PROMOTEDELIVERYRESP']._serialized_end=7565
  _globals['_BYPASSPROTECTIONREQ']._serialized_start=7567
  _globals['_BYPASSPROTECTIONREQ']._serialized_end=7648
  _globals['_BYPASSPROTECTIONRESP']._serialized_start=7650
  _globals['_BYPASSPROTECTIONRESP']._serialized_end=7672
  _globals['_LISTMAESTRORELEASESREQ']._serialized_start=7675
  _globals['_LISTMAESTRORELEASESREQ']._serialized_end=7858
  _globals['_LISTMAESTRORELEASESRESP']._serialized_start=7860
  _globals['_LISTMAESTRORELEASESRESP']._serialized_end=7984
  _globals['_GETMAESTRORELEASEREQ']._serialized_start=7986
  _globals['_GETMAESTRORELEASEREQ']._serialized_end=8037
  _globals['_GETMAESTRORELEASERESP']._serialized_start=8039
  _globals['_GETMAESTRORELEASERESP']._serialized_end=8135
  _globals['_LISTCOMBINEDRELEASESREQ']._serialized_start=8138
  _globals['_LISTCOMBINEDRELEASESREQ']._serialized_end=8293
  _globals['_LISTSERVICECOMBINEDRELEASESREQ']._serialized_start=8296
  _globals['_LISTSERVICECOMBINEDRELEASESREQ']._serialized_end=8443
  _globals['_LISTCOMBINEDRELEASESRESP']._serialized_start=8446
  _globals['_LISTCOMBINEDRELEASESRESP']._serialized_end=8708
  _globals['_LISTCOMBINEDRELEASESRESP_RELEASE']._serialized_start=8576
  _globals['_LISTCOMBINEDRELEASESRESP_RELEASE']._serialized_end=8708
  _globals['_GETLATESTCOMBINEDRELEASEDESIREDSTATEREQ']._serialized_start=8710
  _globals['_GETLATESTCOMBINEDRELEASEDESIREDSTATEREQ']._serialized_end=8822
  _globals['_GETSERVICELATESTCOMBINEDRELEASEDESIREDSTATEREQ']._serialized_start=8824
  _globals['_GETSERVICELATESTCOMBINEDRELEASEDESIREDSTATEREQ']._serialized_end=8928
  _globals['_GETLATESTCOMBINEDRELEASEDESIREDSTATERESP']._serialized_start=8931
  _globals['_GETLATESTCOMBINEDRELEASEDESIREDSTATERESP']._serialized_end=9356
  _globals['_DESIREDSTATEMANAGER']._serialized_start=9359
  _globals['_DESIREDSTATEMANAGER']._serialized_end=13484
# @@protoc_insertion_point(module_scope)
