# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/config_file/config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from prodvana.proto.prodvana.application import application_config_pb2 as prodvana_dot_application_dot_application__config__pb2
from prodvana.proto.prodvana.application import user_metadata_pb2 as prodvana_dot_application_dot_user__metadata__pb2
from prodvana.proto.prodvana.environment import clusters_pb2 as prodvana_dot_environment_dot_clusters__pb2
from prodvana.proto.prodvana.delivery_extension import config_pb2 as prodvana_dot_delivery__extension_dot_config__pb2
from prodvana.proto.prodvana.protection import protection_config_pb2 as prodvana_dot_protection_dot_protection__config__pb2
from prodvana.proto.prodvana.release_channel import release_channel_config_pb2 as prodvana_dot_release__channel_dot_release__channel__config__pb2
from prodvana.proto.prodvana.service import service_config_pb2 as prodvana_dot_service_dot_service__config__pb2
from prodvana.proto.prodvana.service import user_metadata_pb2 as prodvana_dot_service_dot_user__metadata__pb2
from prodvana.proto.validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!prodvana/config_file/config.proto\x12\x14prodvana.config_file\x1a-prodvana/application/application_config.proto\x1a(prodvana/application/user_metadata.proto\x1a#prodvana/environment/clusters.proto\x1a(prodvana/delivery_extension/config.proto\x1a+prodvana/protection/protection_config.proto\x1a\x35prodvana/release_channel/release_channel_config.proto\x1a%prodvana/service/service_config.proto\x1a$prodvana/service/user_metadata.proto\x1a\x17validate/validate.proto\"\xd1\x04\n\x0eProdvanaConfig\x12>\n\x0b\x61pplication\x18\x01 \x01(\x0b\x32\'.prodvana.application.ApplicationConfigH\x00\x12\x32\n\x07service\x18\x02 \x01(\x0b\x32\x1f.prodvana.service.ServiceConfigH\x00\x12;\n\nprotection\x18\x03 \x01(\x0b\x32%.prodvana.protection.ProtectionConfigH\x00\x12\x36\n\x07runtime\x18\x04 \x01(\x0b\x32#.prodvana.environment.ClusterConfigH\x00\x12R\n\x12\x64\x65livery_extension\x18\x07 \x01(\x0b\x32\x34.prodvana.delivery_extension.DeliveryExtensionConfigH\x00\x12I\n\x0frelease_channel\x18\x08 \x01(\x0b\x32..prodvana.release_channel.ReleaseChannelConfigH\x00\x12M\n\x14\x61pplication_metadata\x18\x05 \x01(\x0b\x32-.prodvana.application.ApplicationUserMetadataH\x01\x12\x41\n\x10service_metadata\x18\x06 \x01(\x0b\x32%.prodvana.service.ServiceUserMetadataH\x01\x42\x13\n\x0c\x63onfig_oneof\x12\x03\xf8\x42\x01\x42\x10\n\x0emetadata_oneofBPZNgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/config_fileb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'prodvana.config_file.config_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZNgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/config_file'
  _PRODVANACONFIG.oneofs_by_name['config_oneof']._options = None
  _PRODVANACONFIG.oneofs_by_name['config_oneof']._serialized_options = b'\370B\001'
  _globals['_PRODVANACONFIG']._serialized_start=430
  _globals['_PRODVANACONFIG']._serialized_end=1023
# @@protoc_insertion_point(module_scope)
