# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/config_writeback/writeback.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)prodvana/config_writeback/writeback.proto\x12\x19prodvana.config_writeback\"A\n\x13\x43onfigWritebackPath\x12\x14\n\x0c\x64isplay_name\x18\x01 \x01(\t\x12\x14\n\x0c\x64isplay_path\x18\x02 \x01(\tBUZSgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/config_writebackb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'prodvana.config_writeback.writeback_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZSgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/config_writeback'
  _globals['_CONFIGWRITEBACKPATH']._serialized_start=72
  _globals['_CONFIGWRITEBACKPATH']._serialized_end=137
# @@protoc_insertion_point(module_scope)
