"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import prodvana.proto.prodvana.common_config.links_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class OrganizationUserMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APPLICATION_LINKS_FIELD_NUMBER: builtins.int
    SERVICE_LINKS_FIELD_NUMBER: builtins.int
    LINKS_FIELD_NUMBER: builtins.int
    @property
    def application_links(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[prodvana.proto.prodvana.common_config.links_pb2.Link]:
        """Links that every app should get automatically"""
    @property
    def service_links(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[prodvana.proto.prodvana.common_config.links_pb2.Link]:
        """Links that every service should get automatically"""
    @property
    def links(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[prodvana.proto.prodvana.common_config.links_pb2.Link]: ...
    def __init__(
        self,
        *,
        application_links: collections.abc.Iterable[prodvana.proto.prodvana.common_config.links_pb2.Link] | None = ...,
        service_links: collections.abc.Iterable[prodvana.proto.prodvana.common_config.links_pb2.Link] | None = ...,
        links: collections.abc.Iterable[prodvana.proto.prodvana.common_config.links_pb2.Link] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["application_links", b"application_links", "links", b"links", "service_links", b"service_links"]) -> None: ...

global___OrganizationUserMetadata = OrganizationUserMetadata
