"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import prodvana.proto.prodvana.events.events_pb2
import prodvana.proto.prodvana.release_channel.object_pb2
import prodvana.proto.prodvana.release_channel.release_channel_config_pb2
import prodvana.proto.prodvana.version.source_metadata_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class ConfigureReleaseChannelReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APPLICATION_FIELD_NUMBER: builtins.int
    RELEASE_CHANNEL_FIELD_NUMBER: builtins.int
    SOURCE_FIELD_NUMBER: builtins.int
    SOURCE_METADATA_FIELD_NUMBER: builtins.int
    FORCE_CREATE_NEW_VERSION_FIELD_NUMBER: builtins.int
    application: builtins.str
    @property
    def release_channel(self) -> prodvana.proto.prodvana.release_channel.release_channel_config_pb2.ReleaseChannelConfig: ...
    source: prodvana.proto.prodvana.version.source_metadata_pb2.Source.ValueType
    @property
    def source_metadata(self) -> prodvana.proto.prodvana.version.source_metadata_pb2.SourceMetadata: ...
    force_create_new_version: builtins.bool
    """create new version even if there are no detected changes"""
    def __init__(
        self,
        *,
        application: builtins.str = ...,
        release_channel: prodvana.proto.prodvana.release_channel.release_channel_config_pb2.ReleaseChannelConfig | None = ...,
        source: prodvana.proto.prodvana.version.source_metadata_pb2.Source.ValueType = ...,
        source_metadata: prodvana.proto.prodvana.version.source_metadata_pb2.SourceMetadata | None = ...,
        force_create_new_version: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["release_channel", b"release_channel", "source_metadata", b"source_metadata"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["application", b"application", "force_create_new_version", b"force_create_new_version", "release_channel", b"release_channel", "source", b"source", "source_metadata", b"source_metadata"]) -> None: ...

global___ConfigureReleaseChannelReq = ConfigureReleaseChannelReq

class ConfigureReleaseChannelResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VERSION_FIELD_NUMBER: builtins.int
    CREATED_NEW_VERSION_FIELD_NUMBER: builtins.int
    version: builtins.str
    """application version"""
    created_new_version: builtins.bool
    def __init__(
        self,
        *,
        version: builtins.str = ...,
        created_new_version: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["created_new_version", b"created_new_version", "version", b"version"]) -> None: ...

global___ConfigureReleaseChannelResp = ConfigureReleaseChannelResp

class DeleteReleaseChannelReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RELEASE_CHANNEL_FIELD_NUMBER: builtins.int
    APPLICATION_FIELD_NUMBER: builtins.int
    SOURCE_FIELD_NUMBER: builtins.int
    SOURCE_METADATA_FIELD_NUMBER: builtins.int
    release_channel: builtins.str
    application: builtins.str
    source: prodvana.proto.prodvana.version.source_metadata_pb2.Source.ValueType
    @property
    def source_metadata(self) -> prodvana.proto.prodvana.version.source_metadata_pb2.SourceMetadata: ...
    def __init__(
        self,
        *,
        release_channel: builtins.str = ...,
        application: builtins.str = ...,
        source: prodvana.proto.prodvana.version.source_metadata_pb2.Source.ValueType = ...,
        source_metadata: prodvana.proto.prodvana.version.source_metadata_pb2.SourceMetadata | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["source_metadata", b"source_metadata"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["application", b"application", "release_channel", b"release_channel", "source", b"source", "source_metadata", b"source_metadata"]) -> None: ...

global___DeleteReleaseChannelReq = DeleteReleaseChannelReq

class DeleteReleaseChannelResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VERSION_FIELD_NUMBER: builtins.int
    version: builtins.str
    """application version"""
    def __init__(
        self,
        *,
        version: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["version", b"version"]) -> None: ...

global___DeleteReleaseChannelResp = DeleteReleaseChannelResp

class ListReleaseChannelsReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APPLICATION_FIELD_NUMBER: builtins.int
    application: builtins.str
    def __init__(
        self,
        *,
        application: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["application", b"application"]) -> None: ...

global___ListReleaseChannelsReq = ListReleaseChannelsReq

class ListReleaseChannelsResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RELEASE_CHANNELS_FIELD_NUMBER: builtins.int
    @property
    def release_channels(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[prodvana.proto.prodvana.release_channel.object_pb2.ReleaseChannel]: ...
    def __init__(
        self,
        *,
        release_channels: collections.abc.Iterable[prodvana.proto.prodvana.release_channel.object_pb2.ReleaseChannel] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["release_channels", b"release_channels"]) -> None: ...

global___ListReleaseChannelsResp = ListReleaseChannelsResp

class GetReleaseChannelReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APPLICATION_FIELD_NUMBER: builtins.int
    RELEASE_CHANNEL_FIELD_NUMBER: builtins.int
    application: builtins.str
    release_channel: builtins.str
    def __init__(
        self,
        *,
        application: builtins.str = ...,
        release_channel: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["application", b"application", "release_channel", b"release_channel"]) -> None: ...

global___GetReleaseChannelReq = GetReleaseChannelReq

class GetReleaseChannelResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RELEASE_CHANNEL_FIELD_NUMBER: builtins.int
    @property
    def release_channel(self) -> prodvana.proto.prodvana.release_channel.object_pb2.ReleaseChannel: ...
    def __init__(
        self,
        *,
        release_channel: prodvana.proto.prodvana.release_channel.object_pb2.ReleaseChannel | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["release_channel", b"release_channel"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["release_channel", b"release_channel"]) -> None: ...

global___GetReleaseChannelResp = GetReleaseChannelResp

class GetReleaseChannelConfigReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APPLICATION_FIELD_NUMBER: builtins.int
    RELEASE_CHANNEL_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    application: builtins.str
    release_channel: builtins.str
    version: builtins.str
    """omit to get latest version"""
    def __init__(
        self,
        *,
        application: builtins.str = ...,
        release_channel: builtins.str = ...,
        version: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["application", b"application", "release_channel", b"release_channel", "version", b"version"]) -> None: ...

global___GetReleaseChannelConfigReq = GetReleaseChannelConfigReq

class GetReleaseChannelConfigResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONFIG_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    COMPILED_CONFIG_FIELD_NUMBER: builtins.int
    @property
    def config(self) -> prodvana.proto.prodvana.release_channel.release_channel_config_pb2.ReleaseChannelConfig:
        """config as passed in by user"""
    version: builtins.str
    @property
    def compiled_config(self) -> prodvana.proto.prodvana.release_channel.release_channel_config_pb2.ReleaseChannelConfig:
        """config with defaults applied"""
    def __init__(
        self,
        *,
        config: prodvana.proto.prodvana.release_channel.release_channel_config_pb2.ReleaseChannelConfig | None = ...,
        version: builtins.str = ...,
        compiled_config: prodvana.proto.prodvana.release_channel.release_channel_config_pb2.ReleaseChannelConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["compiled_config", b"compiled_config", "config", b"config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["compiled_config", b"compiled_config", "config", b"config", "version", b"version"]) -> None: ...

global___GetReleaseChannelConfigResp = GetReleaseChannelConfigResp

class GetReleaseChannelEventsReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APPLICATION_FIELD_NUMBER: builtins.int
    RELEASE_CHANNEL_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    ORDER_BY_DESC_TIMESTAMP_FIELD_NUMBER: builtins.int
    application: builtins.str
    release_channel: builtins.str
    page_token: builtins.str
    page_size: builtins.int
    order_by_desc_timestamp: builtins.bool
    def __init__(
        self,
        *,
        application: builtins.str = ...,
        release_channel: builtins.str = ...,
        page_token: builtins.str = ...,
        page_size: builtins.int = ...,
        order_by_desc_timestamp: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["application", b"application", "order_by_desc_timestamp", b"order_by_desc_timestamp", "page_size", b"page_size", "page_token", b"page_token", "release_channel", b"release_channel"]) -> None: ...

global___GetReleaseChannelEventsReq = GetReleaseChannelEventsReq

class GetReleaseChannelEventsResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EVENTS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    @property
    def events(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[prodvana.proto.prodvana.events.events_pb2.Event]: ...
    next_page_token: builtins.str
    def __init__(
        self,
        *,
        events: collections.abc.Iterable[prodvana.proto.prodvana.events.events_pb2.Event] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["events", b"events", "next_page_token", b"next_page_token"]) -> None: ...

global___GetReleaseChannelEventsResp = GetReleaseChannelEventsResp
