# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/delivery_extension/manager.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from prodvana.proto.prodvana.delivery_extension import object_pb2 as prodvana_dot_delivery__extension_dot_object__pb2
from prodvana.proto.prodvana.delivery_extension import config_pb2 as prodvana_dot_delivery__extension_dot_config__pb2
from prodvana.proto.prodvana.version import source_metadata_pb2 as prodvana_dot_version_dot_source__metadata__pb2
from prodvana.proto.validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)prodvana/delivery_extension/manager.proto\x12\x1bprodvana.delivery_extension\x1a\x1cgoogle/api/annotations.proto\x1a(prodvana/delivery_extension/object.proto\x1a(prodvana/delivery_extension/config.proto\x1a&prodvana/version/source_metadata.proto\x1a\x17validate/validate.proto\"\xe7\x01\n\x1d\x43onfigureDeliveryExtensionReq\x12\x61\n\x19\x64\x65livery_extension_config\x18\x01 \x01(\x0b\x32\x34.prodvana.delivery_extension.DeliveryExtensionConfigB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12(\n\x06source\x18\x02 \x01(\x0e\x32\x18.prodvana.version.Source\x12\x39\n\x0fsource_metadata\x18\x03 \x01(\x0b\x32 .prodvana.version.SourceMetadata\"P\n\x1e\x43onfigureDeliveryExtensionResp\x12\x1d\n\x15\x64\x65livery_extension_id\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\"\xc3\x01\n&ValidateConfigureDeliveryExtensionResp\x12J\n\x0cinput_config\x18\x01 \x01(\x0b\x32\x34.prodvana.delivery_extension.DeliveryExtensionConfig\x12M\n\x0f\x63ompiled_config\x18\x02 \x01(\x0b\x32\x34.prodvana.delivery_extension.DeliveryExtensionConfig\"B\n\x19ListDeliveryExtensionsReq\x12\x12\n\npage_token\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\"\x82\x01\n\x1aListDeliveryExtensionsResp\x12K\n\x13\x64\x65livery_extensions\x18\x01 \x03(\x0b\x32..prodvana.delivery_extension.DeliveryExtension\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\">\n\x17GetDeliveryExtensionReq\x12#\n\x12\x64\x65livery_extension\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\"f\n\x18GetDeliveryExtensionResp\x12J\n\x12\x64\x65livery_extension\x18\x01 \x01(\x0b\x32..prodvana.delivery_extension.DeliveryExtension\"U\n\x1dGetDeliveryExtensionConfigReq\x12#\n\x12\x64\x65livery_extension\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x0f\n\x07version\x18\x02 \x01(\t\"\xcc\x01\n\x1eGetDeliveryExtensionConfigResp\x12J\n\x0cinput_config\x18\x01 \x01(\x0b\x32\x34.prodvana.delivery_extension.DeliveryExtensionConfig\x12M\n\x0f\x63ompiled_config\x18\x03 \x01(\x0b\x32\x34.prodvana.delivery_extension.DeliveryExtensionConfig\x12\x0f\n\x07version\x18\x02 \x01(\t\"i\n%GetDeliveryExtensionInstanceConfigReq\x12/\n\x1e\x64\x65livery_extension_instance_id\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x0f\n\x07version\x18\x02 \x01(\t\"\x8f\x01\n&GetDeliveryExtensionInstanceConfigResp\x12T\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x44.prodvana.delivery_extension.CompiledDeliveryExtensionInstanceConfig\x12\x0f\n\x07version\x18\x02 \x01(\t2\x82\n\n\x18\x44\x65liveryExtensionManager\x12\xc3\x01\n\x1a\x43onfigureDeliveryExtension\x12:.prodvana.delivery_extension.ConfigureDeliveryExtensionReq\x1a;.prodvana.delivery_extension.ConfigureDeliveryExtensionResp\",\x82\xd3\xe4\x93\x02&\"!/v1/delivery_extensions/configure:\x01*\x12\xdc\x01\n\"ValidateConfigureDeliveryExtension\x12:.prodvana.delivery_extension.ConfigureDeliveryExtensionReq\x1a\x43.prodvana.delivery_extension.ValidateConfigureDeliveryExtensionResp\"5\x82\xd3\xe4\x93\x02/\"*/v1/delivery_extensions/configure/validate:\x01*\x12\xaa\x01\n\x16ListDeliveryExtensions\x12\x36.prodvana.delivery_extension.ListDeliveryExtensionsReq\x1a\x37.prodvana.delivery_extension.ListDeliveryExtensionsResp\"\x1f\x82\xd3\xe4\x93\x02\x19\x12\x17/v1/delivery_extensions\x12\xba\x01\n\x14GetDeliveryExtension\x12\x34.prodvana.delivery_extension.GetDeliveryExtensionReq\x1a\x35.prodvana.delivery_extension.GetDeliveryExtensionResp\"5\x82\xd3\xe4\x93\x02/\x12-/v1/delivery_extension/{delivery_extension=*}\x12\xd3\x01\n\x1aGetDeliveryExtensionConfig\x12:.prodvana.delivery_extension.GetDeliveryExtensionConfigReq\x1a;.prodvana.delivery_extension.GetDeliveryExtensionConfigResp\"<\x82\xd3\xe4\x93\x02\x36\x12\x34/v1/delivery_extension/{delivery_extension=*}/config\x12\x80\x02\n\"GetDeliveryExtensionInstanceConfig\x12\x42.prodvana.delivery_extension.GetDeliveryExtensionInstanceConfigReq\x1a\x43.prodvana.delivery_extension.GetDeliveryExtensionInstanceConfigResp\"Q\x82\xd3\xe4\x93\x02K\x12I/v1/delivery_extension/instance/{delivery_extension_instance_id=*}/configBWZUgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/delivery_extensionb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'prodvana.delivery_extension.manager_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZUgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/delivery_extension'
  _CONFIGUREDELIVERYEXTENSIONREQ.fields_by_name['delivery_extension_config']._options = None
  _CONFIGUREDELIVERYEXTENSIONREQ.fields_by_name['delivery_extension_config']._serialized_options = b'\372B\005\212\001\002\020\001'
  _GETDELIVERYEXTENSIONREQ.fields_by_name['delivery_extension']._options = None
  _GETDELIVERYEXTENSIONREQ.fields_by_name['delivery_extension']._serialized_options = b'\372B\004r\002\020\001'
  _GETDELIVERYEXTENSIONCONFIGREQ.fields_by_name['delivery_extension']._options = None
  _GETDELIVERYEXTENSIONCONFIGREQ.fields_by_name['delivery_extension']._serialized_options = b'\372B\004r\002\020\001'
  _GETDELIVERYEXTENSIONINSTANCECONFIGREQ.fields_by_name['delivery_extension_instance_id']._options = None
  _GETDELIVERYEXTENSIONINSTANCECONFIGREQ.fields_by_name['delivery_extension_instance_id']._serialized_options = b'\372B\004r\002\020\001'
  _DELIVERYEXTENSIONMANAGER.methods_by_name['ConfigureDeliveryExtension']._options = None
  _DELIVERYEXTENSIONMANAGER.methods_by_name['ConfigureDeliveryExtension']._serialized_options = b'\202\323\344\223\002&\"!/v1/delivery_extensions/configure:\001*'
  _DELIVERYEXTENSIONMANAGER.methods_by_name['ValidateConfigureDeliveryExtension']._options = None
  _DELIVERYEXTENSIONMANAGER.methods_by_name['ValidateConfigureDeliveryExtension']._serialized_options = b'\202\323\344\223\002/\"*/v1/delivery_extensions/configure/validate:\001*'
  _DELIVERYEXTENSIONMANAGER.methods_by_name['ListDeliveryExtensions']._options = None
  _DELIVERYEXTENSIONMANAGER.methods_by_name['ListDeliveryExtensions']._serialized_options = b'\202\323\344\223\002\031\022\027/v1/delivery_extensions'
  _DELIVERYEXTENSIONMANAGER.methods_by_name['GetDeliveryExtension']._options = None
  _DELIVERYEXTENSIONMANAGER.methods_by_name['GetDeliveryExtension']._serialized_options = b'\202\323\344\223\002/\022-/v1/delivery_extension/{delivery_extension=*}'
  _DELIVERYEXTENSIONMANAGER.methods_by_name['GetDeliveryExtensionConfig']._options = None
  _DELIVERYEXTENSIONMANAGER.methods_by_name['GetDeliveryExtensionConfig']._serialized_options = b'\202\323\344\223\0026\0224/v1/delivery_extension/{delivery_extension=*}/config'
  _DELIVERYEXTENSIONMANAGER.methods_by_name['GetDeliveryExtensionInstanceConfig']._options = None
  _DELIVERYEXTENSIONMANAGER.methods_by_name['GetDeliveryExtensionInstanceConfig']._serialized_options = b'\202\323\344\223\002K\022I/v1/delivery_extension/instance/{delivery_extension_instance_id=*}/config'
  _globals['_CONFIGUREDELIVERYEXTENSIONREQ']._serialized_start=254
  _globals['_CONFIGUREDELIVERYEXTENSIONREQ']._serialized_end=485
  _globals['_CONFIGUREDELIVERYEXTENSIONRESP']._serialized_start=487
  _globals['_CONFIGUREDELIVERYEXTENSIONRESP']._serialized_end=567
  _globals['_VALIDATECONFIGUREDELIVERYEXTENSIONRESP']._serialized_start=570
  _globals['_VALIDATECONFIGUREDELIVERYEXTENSIONRESP']._serialized_end=765
  _globals['_LISTDELIVERYEXTENSIONSREQ']._serialized_start=767
  _globals['_LISTDELIVERYEXTENSIONSREQ']._serialized_end=833
  _globals['_LISTDELIVERYEXTENSIONSRESP']._serialized_start=836
  _globals['_LISTDELIVERYEXTENSIONSRESP']._serialized_end=966
  _globals['_GETDELIVERYEXTENSIONREQ']._serialized_start=968
  _globals['_GETDELIVERYEXTENSIONREQ']._serialized_end=1030
  _globals['_GETDELIVERYEXTENSIONRESP']._serialized_start=1032
  _globals['_GETDELIVERYEXTENSIONRESP']._serialized_end=1134
  _globals['_GETDELIVERYEXTENSIONCONFIGREQ']._serialized_start=1136
  _globals['_GETDELIVERYEXTENSIONCONFIGREQ']._serialized_end=1221
  _globals['_GETDELIVERYEXTENSIONCONFIGRESP']._serialized_start=1224
  _globals['_GETDELIVERYEXTENSIONCONFIGRESP']._serialized_end=1428
  _globals['_GETDELIVERYEXTENSIONINSTANCECONFIGREQ']._serialized_start=1430
  _globals['_GETDELIVERYEXTENSIONINSTANCECONFIGREQ']._serialized_end=1535
  _globals['_GETDELIVERYEXTENSIONINSTANCECONFIGRESP']._serialized_start=1538
  _globals['_GETDELIVERYEXTENSIONINSTANCECONFIGRESP']._serialized_end=1681
  _globals['_DELIVERYEXTENSIONMANAGER']._serialized_start=1684
  _globals['_DELIVERYEXTENSIONMANAGER']._serialized_end=2966
# @@protoc_insertion_point(module_scope)
