# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/settings/organization/roles.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*prodvana/settings/organization/roles.proto\x12\x1eprodvana.settings.organization*V\n\x04Role\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\r\n\tORG_ADMIN\x10\x01\x12\x0f\n\x0b\x43LOUD_ADMIN\x10\x02\x12\x11\n\rSERVICE_OWNER\x10\x03\x12\n\n\x06VIEWER\x10\x04\x42ZZXgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/settings/organizationb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'prodvana.settings.organization.roles_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZXgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/settings/organization'
  _globals['_ROLE']._serialized_start=78
  _globals['_ROLE']._serialized_end=164
# @@protoc_insertion_point(module_scope)
