"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.duration_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class DeploymentMetrics(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class Deltas(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        TOTAL_DEPLOYMENTS_FIELD_NUMBER: builtins.int
        SUCCESSFUL_DEPLOYMENTS_FIELD_NUMBER: builtins.int
        SUCCESSFUL_DEPLOYMENTS_PER_DAY_FIELD_NUMBER: builtins.int
        FAILED_DEPLOYMENTS_FIELD_NUMBER: builtins.int
        MEDIAN_SUCCESSFUL_DEPLOYMENT_DURATION_FIELD_NUMBER: builtins.int
        DEPLOYMENT_FAILURE_RATE_FIELD_NUMBER: builtins.int
        TOTAL_ROLLBACKS_FIELD_NUMBER: builtins.int
        SUCCESSFUL_ROLLBACKS_FIELD_NUMBER: builtins.int
        MEDIAN_SUCCESSFUL_ROLLBACK_DURATION_FIELD_NUMBER: builtins.int
        total_deployments: builtins.float
        successful_deployments: builtins.float
        successful_deployments_per_day: builtins.float
        failed_deployments: builtins.float
        median_successful_deployment_duration: builtins.float
        deployment_failure_rate: builtins.float
        total_rollbacks: builtins.float
        successful_rollbacks: builtins.float
        median_successful_rollback_duration: builtins.float
        def __init__(
            self,
            *,
            total_deployments: builtins.float = ...,
            successful_deployments: builtins.float = ...,
            successful_deployments_per_day: builtins.float = ...,
            failed_deployments: builtins.float = ...,
            median_successful_deployment_duration: builtins.float = ...,
            deployment_failure_rate: builtins.float = ...,
            total_rollbacks: builtins.float = ...,
            successful_rollbacks: builtins.float = ...,
            median_successful_rollback_duration: builtins.float = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["deployment_failure_rate", b"deployment_failure_rate", "failed_deployments", b"failed_deployments", "median_successful_deployment_duration", b"median_successful_deployment_duration", "median_successful_rollback_duration", b"median_successful_rollback_duration", "successful_deployments", b"successful_deployments", "successful_deployments_per_day", b"successful_deployments_per_day", "successful_rollbacks", b"successful_rollbacks", "total_deployments", b"total_deployments", "total_rollbacks", b"total_rollbacks"]) -> None: ...

    class Values(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        TOTAL_DEPLOYMENTS_FIELD_NUMBER: builtins.int
        SUCCESSFUL_DEPLOYMENTS_FIELD_NUMBER: builtins.int
        SUCCESSFUL_DEPLOYMENTS_PER_DAY_FIELD_NUMBER: builtins.int
        FAILED_DEPLOYMENTS_FIELD_NUMBER: builtins.int
        MEDIAN_SUCCESSFUL_DEPLOYMENT_DURATION_FIELD_NUMBER: builtins.int
        DEPLOYMENT_FAILURE_RATE_FIELD_NUMBER: builtins.int
        TOTAL_ROLLBACKS_FIELD_NUMBER: builtins.int
        SUCCESSFUL_ROLLBACKS_FIELD_NUMBER: builtins.int
        MEDIAN_SUCCESSFUL_ROLLBACK_DURATION_FIELD_NUMBER: builtins.int
        LAST_SUCCESSFUL_DEPLOYMENT_COMPLETION_TIME_FIELD_NUMBER: builtins.int
        total_deployments: builtins.float
        successful_deployments: builtins.float
        successful_deployments_per_day: builtins.float
        failed_deployments: builtins.float
        @property
        def median_successful_deployment_duration(self) -> google.protobuf.duration_pb2.Duration: ...
        deployment_failure_rate: builtins.float
        total_rollbacks: builtins.float
        successful_rollbacks: builtins.float
        @property
        def median_successful_rollback_duration(self) -> google.protobuf.duration_pb2.Duration: ...
        @property
        def last_successful_deployment_completion_time(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
        def __init__(
            self,
            *,
            total_deployments: builtins.float = ...,
            successful_deployments: builtins.float = ...,
            successful_deployments_per_day: builtins.float = ...,
            failed_deployments: builtins.float = ...,
            median_successful_deployment_duration: google.protobuf.duration_pb2.Duration | None = ...,
            deployment_failure_rate: builtins.float = ...,
            total_rollbacks: builtins.float = ...,
            successful_rollbacks: builtins.float = ...,
            median_successful_rollback_duration: google.protobuf.duration_pb2.Duration | None = ...,
            last_successful_deployment_completion_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["last_successful_deployment_completion_time", b"last_successful_deployment_completion_time", "median_successful_deployment_duration", b"median_successful_deployment_duration", "median_successful_rollback_duration", b"median_successful_rollback_duration"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["deployment_failure_rate", b"deployment_failure_rate", "failed_deployments", b"failed_deployments", "last_successful_deployment_completion_time", b"last_successful_deployment_completion_time", "median_successful_deployment_duration", b"median_successful_deployment_duration", "median_successful_rollback_duration", b"median_successful_rollback_duration", "successful_deployments", b"successful_deployments", "successful_deployments_per_day", b"successful_deployments_per_day", "successful_rollbacks", b"successful_rollbacks", "total_deployments", b"total_deployments", "total_rollbacks", b"total_rollbacks"]) -> None: ...

    class TimeseriesMetrics(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        TIMESTAMP_FIELD_NUMBER: builtins.int
        SUCCESSFUL_DEPLOYMENTS_FIELD_NUMBER: builtins.int
        FAILED_DEPLOYMENTS_FIELD_NUMBER: builtins.int
        @property
        def timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
        successful_deployments: builtins.float
        failed_deployments: builtins.float
        def __init__(
            self,
            *,
            timestamp: google.protobuf.timestamp_pb2.Timestamp | None = ...,
            successful_deployments: builtins.float = ...,
            failed_deployments: builtins.float = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["timestamp", b"timestamp"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["failed_deployments", b"failed_deployments", "successful_deployments", b"successful_deployments", "timestamp", b"timestamp"]) -> None: ...

    VALUES_FIELD_NUMBER: builtins.int
    TIMESERIES_FIELD_NUMBER: builtins.int
    DELTAS_FIELD_NUMBER: builtins.int
    @property
    def values(self) -> global___DeploymentMetrics.Values: ...
    @property
    def timeseries(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DeploymentMetrics.TimeseriesMetrics]: ...
    @property
    def deltas(self) -> global___DeploymentMetrics.Deltas: ...
    def __init__(
        self,
        *,
        values: global___DeploymentMetrics.Values | None = ...,
        timeseries: collections.abc.Iterable[global___DeploymentMetrics.TimeseriesMetrics] | None = ...,
        deltas: global___DeploymentMetrics.Deltas | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["deltas", b"deltas", "values", b"values"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["deltas", b"deltas", "timeseries", b"timeseries", "values", b"values"]) -> None: ...

global___DeploymentMetrics = DeploymentMetrics

class Cost(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONFIGURED_FIELD_NUMBER: builtins.int
    COST_FIELD_NUMBER: builtins.int
    configured: builtins.bool
    cost: builtins.float
    def __init__(
        self,
        *,
        configured: builtins.bool = ...,
        cost: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["configured", b"configured", "cost", b"cost"]) -> None: ...

global___Cost = Cost
