"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class VolumeSource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class SecretSource(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        SECRET_NAME_FIELD_NUMBER: builtins.int
        secret_name: builtins.str
        def __init__(
            self,
            *,
            secret_name: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["secret_name", b"secret_name"]) -> None: ...

    class EphemeralSource(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        class _Medium:
            ValueType = typing.NewType("ValueType", builtins.int)
            V: typing_extensions.TypeAlias = ValueType

        class _MediumEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[VolumeSource.EphemeralSource._Medium.ValueType], builtins.type):  # noqa: F821
            DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
            UNKNOWN: VolumeSource.EphemeralSource._Medium.ValueType  # 0
            DEFAULT: VolumeSource.EphemeralSource._Medium.ValueType  # 1
            """for kubernetes, this the the node's default storage medium"""
            MEMORY: VolumeSource.EphemeralSource._Medium.ValueType  # 2

        class Medium(_Medium, metaclass=_MediumEnumTypeWrapper): ...
        UNKNOWN: VolumeSource.EphemeralSource.Medium.ValueType  # 0
        DEFAULT: VolumeSource.EphemeralSource.Medium.ValueType  # 1
        """for kubernetes, this the the node's default storage medium"""
        MEMORY: VolumeSource.EphemeralSource.Medium.ValueType  # 2

        MEDIUM_FIELD_NUMBER: builtins.int
        medium: global___VolumeSource.EphemeralSource.Medium.ValueType
        def __init__(
            self,
            *,
            medium: global___VolumeSource.EphemeralSource.Medium.ValueType = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["medium", b"medium"]) -> None: ...

    SECRET_FIELD_NUMBER: builtins.int
    EPHEMERAL_FIELD_NUMBER: builtins.int
    @property
    def secret(self) -> global___VolumeSource.SecretSource: ...
    @property
    def ephemeral(self) -> global___VolumeSource.EphemeralSource: ...
    def __init__(
        self,
        *,
        secret: global___VolumeSource.SecretSource | None = ...,
        ephemeral: global___VolumeSource.EphemeralSource | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["ephemeral", b"ephemeral", "secret", b"secret", "source", b"source"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["ephemeral", b"ephemeral", "secret", b"secret", "source", b"source"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["source", b"source"]) -> typing_extensions.Literal["secret", "ephemeral"] | None: ...

global___VolumeSource = VolumeSource

class VolumeMount(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MOUNT_PATH_FIELD_NUMBER: builtins.int
    READ_ONLY_FIELD_NUMBER: builtins.int
    mount_path: builtins.str
    read_only: builtins.bool
    def __init__(
        self,
        *,
        mount_path: builtins.str = ...,
        read_only: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["mount_path", b"mount_path", "read_only", b"read_only"]) -> None: ...

global___VolumeMount = VolumeMount

class Volume(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    SOURCE_FIELD_NUMBER: builtins.int
    MOUNT_FIELD_NUMBER: builtins.int
    name: builtins.str
    @property
    def source(self) -> global___VolumeSource: ...
    @property
    def mount(self) -> global___VolumeMount: ...
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        source: global___VolumeSource | None = ...,
        mount: global___VolumeMount | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["mount", b"mount", "source", b"source"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["mount", b"mount", "name", b"name", "source", b"source"]) -> None: ...

global___Volume = Volume
