"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.timestamp_pb2
import prodvana.proto.prodvana.auth.auth_pb2
import prodvana.proto.prodvana.users.users_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class GetTokenRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CODE_FIELD_NUMBER: builtins.int
    REDIRECT_URL_FIELD_NUMBER: builtins.int
    FOR_CLI_FIELD_NUMBER: builtins.int
    PRODVANA_ONLY_ADMIN_ORG_FIELD_NUMBER: builtins.int
    code: builtins.str
    redirect_url: builtins.str
    for_cli: builtins.bool
    prodvana_only_admin_org: builtins.bool
    """prodvana internal use"""
    def __init__(
        self,
        *,
        code: builtins.str = ...,
        redirect_url: builtins.str = ...,
        for_cli: builtins.bool = ...,
        prodvana_only_admin_org: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["code", b"code", "for_cli", b"for_cli", "prodvana_only_admin_org", b"prodvana_only_admin_org", "redirect_url", b"redirect_url"]) -> None: ...

global___GetTokenRequest = GetTokenRequest

class GetAuthUrlResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AUTH_URL_FIELD_NUMBER: builtins.int
    auth_url: builtins.str
    def __init__(
        self,
        *,
        auth_url: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["auth_url", b"auth_url"]) -> None: ...

global___GetAuthUrlResponse = GetAuthUrlResponse

class GetAuthUrlRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATE_FIELD_NUMBER: builtins.int
    FOR_CLI_FIELD_NUMBER: builtins.int
    INVITATION_FIELD_NUMBER: builtins.int
    PRODVANA_ONLY_ADMIN_ORG_FIELD_NUMBER: builtins.int
    state: builtins.str
    for_cli: builtins.bool
    invitation: builtins.str
    """optional invitation id for the invite flow"""
    prodvana_only_admin_org: builtins.bool
    """prodvana internal use"""
    def __init__(
        self,
        *,
        state: builtins.str = ...,
        for_cli: builtins.bool = ...,
        invitation: builtins.str = ...,
        prodvana_only_admin_org: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["for_cli", b"for_cli", "invitation", b"invitation", "prodvana_only_admin_org", b"prodvana_only_admin_org", "state", b"state"]) -> None: ...

global___GetAuthUrlRequest = GetAuthUrlRequest

class CliAuthReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___CliAuthReq = CliAuthReq

class CliAuthResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class UserPrompt(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        USER_CODE_FIELD_NUMBER: builtins.int
        VERIFICATION_URI_FIELD_NUMBER: builtins.int
        VERIFICATION_URI_COMPLETE_FIELD_NUMBER: builtins.int
        user_code: builtins.str
        verification_uri: builtins.str
        verification_uri_complete: builtins.str
        def __init__(
            self,
            *,
            user_code: builtins.str = ...,
            verification_uri: builtins.str = ...,
            verification_uri_complete: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["user_code", b"user_code", "verification_uri", b"verification_uri", "verification_uri_complete", b"verification_uri_complete"]) -> None: ...

    USER_PROMPT_FIELD_NUMBER: builtins.int
    TOKEN_FIELD_NUMBER: builtins.int
    @property
    def user_prompt(self) -> global___CliAuthResp.UserPrompt: ...
    @property
    def token(self) -> prodvana.proto.prodvana.auth.auth_pb2.AuthToken: ...
    def __init__(
        self,
        *,
        user_prompt: global___CliAuthResp.UserPrompt | None = ...,
        token: prodvana.proto.prodvana.auth.auth_pb2.AuthToken | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resp_oneof", b"resp_oneof", "token", b"token", "user_prompt", b"user_prompt"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resp_oneof", b"resp_oneof", "token", b"token", "user_prompt", b"user_prompt"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["resp_oneof", b"resp_oneof"]) -> typing_extensions.Literal["user_prompt", "token"] | None: ...

global___CliAuthResp = CliAuthResp

class RefreshTokenReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TOKEN_FIELD_NUMBER: builtins.int
    FOR_CLI_FIELD_NUMBER: builtins.int
    PRODVANA_ONLY_ADMIN_ORG_FIELD_NUMBER: builtins.int
    @property
    def token(self) -> prodvana.proto.prodvana.auth.auth_pb2.AuthToken: ...
    for_cli: builtins.bool
    prodvana_only_admin_org: builtins.bool
    """prodvana internal use"""
    def __init__(
        self,
        *,
        token: prodvana.proto.prodvana.auth.auth_pb2.AuthToken | None = ...,
        for_cli: builtins.bool = ...,
        prodvana_only_admin_org: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["token", b"token"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["for_cli", b"for_cli", "prodvana_only_admin_org", b"prodvana_only_admin_org", "token", b"token"]) -> None: ...

global___RefreshTokenReq = RefreshTokenReq

class GetAuthTokenResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TOKEN_FIELD_NUMBER: builtins.int
    USER_FIELD_NUMBER: builtins.int
    @property
    def token(self) -> prodvana.proto.prodvana.auth.auth_pb2.AuthToken: ...
    @property
    def user(self) -> prodvana.proto.prodvana.users.users_pb2.User: ...
    def __init__(
        self,
        *,
        token: prodvana.proto.prodvana.auth.auth_pb2.AuthToken | None = ...,
        user: prodvana.proto.prodvana.users.users_pb2.User | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["token", b"token", "user", b"user"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["token", b"token", "user", b"user"]) -> None: ...

global___GetAuthTokenResp = GetAuthTokenResp

class Empty(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___Empty = Empty

class LogoutReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOR_CLI_FIELD_NUMBER: builtins.int
    REDIRECT_URL_FIELD_NUMBER: builtins.int
    PRODVANA_ONLY_ADMIN_ORG_FIELD_NUMBER: builtins.int
    for_cli: builtins.bool
    redirect_url: builtins.str
    """optional redirect url after logout"""
    prodvana_only_admin_org: builtins.bool
    """prodvana internal use"""
    def __init__(
        self,
        *,
        for_cli: builtins.bool = ...,
        redirect_url: builtins.str = ...,
        prodvana_only_admin_org: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["for_cli", b"for_cli", "prodvana_only_admin_org", b"prodvana_only_admin_org", "redirect_url", b"redirect_url"]) -> None: ...

global___LogoutReq = LogoutReq

class LogoutResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LOGOUT_URL_FIELD_NUMBER: builtins.int
    logout_url: builtins.str
    def __init__(
        self,
        *,
        logout_url: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["logout_url", b"logout_url"]) -> None: ...

global___LogoutResp = LogoutResp

class CreateOrgApiTokenReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXPIRES_TIMESTAMP_FIELD_NUMBER: builtins.int
    name: builtins.str
    description: builtins.str
    @property
    def expires_timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        description: builtins.str = ...,
        expires_timestamp: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["expires_timestamp", b"expires_timestamp"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "expires_timestamp", b"expires_timestamp", "name", b"name"]) -> None: ...

global___CreateOrgApiTokenReq = CreateOrgApiTokenReq

class CreateOrgApiTokenResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_TOKEN_FIELD_NUMBER: builtins.int
    INFO_FIELD_NUMBER: builtins.int
    api_token: builtins.str
    @property
    def info(self) -> prodvana.proto.prodvana.auth.auth_pb2.ApiTokenInfo: ...
    def __init__(
        self,
        *,
        api_token: builtins.str = ...,
        info: prodvana.proto.prodvana.auth.auth_pb2.ApiTokenInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_token", b"api_token", "info", b"info"]) -> None: ...

global___CreateOrgApiTokenResp = CreateOrgApiTokenResp

class DeleteOrgApiTokenReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___DeleteOrgApiTokenReq = DeleteOrgApiTokenReq

class DeleteOrgApiTokenResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___DeleteOrgApiTokenResp = DeleteOrgApiTokenResp

class ListOrgApiTokensReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___ListOrgApiTokensReq = ListOrgApiTokensReq

class ListOrgApiTokensResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TOKENS_FIELD_NUMBER: builtins.int
    @property
    def tokens(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[prodvana.proto.prodvana.auth.auth_pb2.ApiTokenInfo]: ...
    def __init__(
        self,
        *,
        tokens: collections.abc.Iterable[prodvana.proto.prodvana.auth.auth_pb2.ApiTokenInfo] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["tokens", b"tokens"]) -> None: ...

global___ListOrgApiTokensResp = ListOrgApiTokensResp
