# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/delivery_extension/object.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from prodvana.proto.prodvana.object import meta_pb2 as prodvana_dot_object_dot_meta__pb2
from prodvana.proto.prodvana.delivery_extension import config_pb2 as prodvana_dot_delivery__extension_dot_config__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(prodvana/delivery_extension/object.proto\x12\x1bprodvana.delivery_extension\x1a\x1aprodvana/object/meta.proto\x1a(prodvana/delivery_extension/config.proto\"\xc8\x01\n\x11\x44\x65liveryExtension\x12)\n\x04meta\x18\x01 \x01(\x0b\x32\x1b.prodvana.object.ObjectMeta\x12\x44\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x34.prodvana.delivery_extension.DeliveryExtensionConfig\x12\x42\n\x05state\x18\x03 \x01(\x0b\x32\x33.prodvana.delivery_extension.DeliveryExtensionState\"\x18\n\x16\x44\x65liveryExtensionStateBWZUgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/delivery_extensionb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'prodvana.delivery_extension.object_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZUgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/delivery_extension'
  _globals['_DELIVERYEXTENSION']._serialized_start=144
  _globals['_DELIVERYEXTENSION']._serialized_end=344
  _globals['_DELIVERYEXTENSIONSTATE']._serialized_start=346
  _globals['_DELIVERYEXTENSIONSTATE']._serialized_end=370
# @@protoc_insertion_point(module_scope)
